@@ -203,9 +203,18 @@ HerculesRMX.Deck.prototype.keypad1Handler = function(value) {
       } else if(this.shiftMode) {
          engine.setValue(this.group,"hotcue_1_clear", 1);
       } else {
-         engine.setValue(this.group,"hotcue_1_activate", 1);
+         engine.setValue(this.group, "hotcue_1_activate", 1);
       }
    }
+   else { // On button release
+    if(!HerculesRMX.shiftMode) {
+      if(this.shiftMode) {
+         engine.setValue(this.group,"hotcue_1_clear", 0);
+      } else {
+         engine.setValue(this.group,"hotcue_1_activate", 0);
+      }
+  }
+}
 };
 
 HerculesRMX.Deck.prototype.keypad2Handler = function(value) {
@@ -216,6 +225,16 @@ HerculesRMX.Deck.prototype.keypad2Handler = function(value) {
          engine.setValue(this.group,"hotcue_2_activate", 1);
       }
    }
+
+   else { // On button release
+    if(!HerculesRMX.shiftMode) {
+      if(this.shiftMode) {
+         engine.setValue(this.group,"hotcue_2_clear", 0);
+      } else {
+         engine.setValue(this.group,"hotcue_2_activate", 0);
+      }
+  }
+}
 };
 
 HerculesRMX.Deck.prototype.keypad3Handler = function(value) {
@@ -226,6 +245,15 @@ HerculesRMX.Deck.prototype.keypad3Handler = function(value) {
          engine.setValue(this.group,"hotcue_3_activate", 1);
       }
    }
+   else { // On button release
+    if(!HerculesRMX.shiftMode) {
+      if(this.shiftMode) {
+         engine.setValue(this.group,"hotcue_3_clear", 0);
+      } else {
+         engine.setValue(this.group,"hotcue_3_activate", 0);
+      }
+  }
+}
 };
 
 HerculesRMX.Deck.prototype.keypad4Handler = function(value) {
@@ -429,7 +457,7 @@ HerculesRMX.Deck.prototype.gainHandler = function(value) {
 HerculesRMX.Deck.prototype.trebleHandler = function(value) {
    if(HerculesRMX.shiftMode) {
       //Flanger
-      Controls.FlangerDepth.setValue("[Flanger]", value);
+      HerculesRMX.Controls.FlangerDepth.setValue("[Flanger]", value);
    } else if(this.shiftMode) {
       //Soft set
       this.Controls.Treble.softMode = true;
@@ -443,7 +471,7 @@ HerculesRMX.Deck.prototype.trebleHandler = function(value) {
 HerculesRMX.Deck.prototype.mediumHandler = function(value) {
    if(HerculesRMX.shiftMode) {
       //Flanger
-      Controls.FlangerDelay.setValue("[Flanger]", value);
+      HerculesRMX.Controls.FlangerDelay.setValue("[Flanger]", value);
    } else if(this.shiftMode) {
       //Soft set
       this.Controls.Medium.softMode = true;
@@ -457,7 +485,7 @@ HerculesRMX.Deck.prototype.mediumHandler = function(value) {
 HerculesRMX.Deck.prototype.bassHandler = function(value) {
    if(HerculesRMX.shiftMode) {
       //Flanger
-      Controls.FlangerPeriod.setValue("[Flanger]", value);
+      HerculesRMX.Controls.FlangerPeriod.setValue("[Flanger]", value);
    } else if(this.shiftMode) {
       //Soft set
       this.Controls.Bass.softMode = true;
