@@ -1,31 +1,27 @@
-
-
 #include <QtDebug>
 #include <time.h>
 #include <math.h>
 
+#include "sampleutil.h"
 #include "trackinfoobject.h"
 #include "analyserrg.h"
-#include "../lib/replaygain/replaygain_analysis.h"
+#include "../lib/replaygain/replaygain.h"
 
 AnalyserGain::AnalyserGain(ConfigObject<ConfigValue> *_config) {
     m_pConfigReplayGain = _config;
-    m_iStepControl = 0;
+    m_bStepControl = false;
     m_pLeftTempBuffer = NULL;
     m_pRightTempBuffer = NULL;
     m_iBufferSize = 0;
+    m_pReplayGain = new ReplayGain();
 }
 
 AnalyserGain::~AnalyserGain() {
     delete [] m_pLeftTempBuffer;
     delete [] m_pRightTempBuffer;
+    delete m_pReplayGain;
 }
 
-//TODO: On may think on rewriting replaygain/replagain_analys.* to improve performances. Anyway those willing to do should be sure of
-//		the resulting values to exactly coincide with "classical" replaygain_analysis.* ones.
-//		On the other hand, every other ReplayGain tagger uses exactly these methods so that we do not have problems about
-//		values to coincide.
-
 void AnalyserGain::initialise(TrackPointer tio, int sampleRate, int totalSamples) {
 
     bool bAnalyserEnabled = (bool)m_pConfigReplayGain->getValueString(ConfigKey("[ReplayGain]","ReplayGainAnalyserEnabled")).toInt();
@@ -35,14 +31,11 @@ void AnalyserGain::initialise(TrackPointer tio, int sampleRate, int totalSamples
         //if (fReplayGain != 0 ) qDebug() << "Found a ReplayGain value of " << 20*log10(fReplayGain) << "dB for track :" <<(tio->getFilename());
         return;
     }
-    m_iStepControl = InitGainAnalysis( (long)sampleRate );
+    m_bStepControl = m_pReplayGain->initialise((long)sampleRate, 2);
 }
 
-
-
-
 void AnalyserGain::process(const CSAMPLE *pIn, const int iLen) {
-    if(m_iStepControl != 1)
+    if(!m_bStepControl)
         return;
 
     int halfLength = static_cast<int>(iLen / 2);
@@ -52,33 +45,30 @@ void AnalyserGain::process(const CSAMPLE *pIn, const int iLen) {
         m_pLeftTempBuffer = new CSAMPLE[halfLength];
         m_pRightTempBuffer = new CSAMPLE[halfLength];
     }
-
-    for (int i = 0; i < halfLength; ++i) {
-        m_pLeftTempBuffer[i] = pIn[i*2] * 32767;
-        m_pRightTempBuffer[i] = pIn[i*2+1] * 32767;
-    }
-    m_iStepControl = AnalyzeSamples(m_pLeftTempBuffer, m_pRightTempBuffer,
-                                    halfLength, 2);
+    SampleUtil::deinterleaveBuffer(m_pLeftTempBuffer, m_pRightTempBuffer, pIn, halfLength);
+    SampleUtil::applyGain(m_pLeftTempBuffer, 32767, halfLength);
+    SampleUtil::applyGain(m_pRightTempBuffer, 32767, halfLength);
+    m_bStepControl = m_pReplayGain->process(m_pLeftTempBuffer, m_pRightTempBuffer, halfLength);
 }
 
-
-
-
 void AnalyserGain::finalise(TrackPointer tio) {
+    if(!m_bStepControl)
+        return;
 
-    if(m_iStepControl!=1) return;
+    float ReplayGainOutput = m_pReplayGain->end();
+    if (ReplayGainOutput == GAIN_NOT_ENOUGH_SAMPLES) {
+        qDebug() << "ReplayGain analysis failed:" << ReplayGainOutput;
+        m_bStepControl = false;
+        return;
+    }
 
-    //TODO: We are going to store values as relative peaks so that "0" means that no replaygain has been evaluated.
-    // This means that we are going to transform from dB to peaks and viceversa.
-    // One may think to digg into replay_gain code and modify it so that
-    // it directly sends results as relative peaks.
-    // In that way there is no need to spend resources in calculating log10 or pow.
+    float fReplayGain_Result = pow(10,(ReplayGainOutput)/20);
 
-    float fReplayGain_Result = pow(10,GetTitleGain()/20);
+    //qDebug() << "ReplayGain result is" << ReplayGainOutput << "pow:" << fReplayGain_Result;
+    //qDebug()<<"ReplayGain outputs "<< ReplayGainOutput << "db for track "<< tio->getFilename();
     tio->setReplayGain(fReplayGain_Result);
     //if(fReplayGain_Result) qDebug() << "ReplayGain Analyser found a ReplayGain value of "<< 20*log10(fReplayGain_Result) << "dB for track " << (tio->getFilename());
-    m_iStepControl=0;
-    fReplayGain_Result=0;
+    m_bStepControl=false;
     //m_iStartTime = clock() - m_iStartTime;
     //qDebug() << "AnalyserGain :: Generation took " << double(m_iStartTime) / CLOCKS_PER_SEC << " seconds";
 }
