@@ -11,9 +11,9 @@
 #include "analyser.h"
 #include "configobject.h"
 
+class ReplayGain;
 
 class AnalyserGain : public Analyser {
-
   public:
     AnalyserGain(ConfigObject<ConfigValue> *_config);
     virtual ~AnalyserGain();
@@ -23,10 +23,11 @@ class AnalyserGain : public Analyser {
     void finalise(TrackPointer tio);
 
   private:
-    int m_iStepControl;
+    bool m_bStepControl;
     ConfigObject<ConfigValue> *m_pConfigReplayGain;
     CSAMPLE* m_pLeftTempBuffer;
     CSAMPLE* m_pRightTempBuffer;
+    ReplayGain *m_pReplayGain;
     int m_iBufferSize;
 };
 
