@@ -32,12 +32,14 @@ public:
     ControlPushButton(ConfigKey key);
     ~ControlPushButton();
     void setToggleButton(bool bIsToggleButton);
+    void setStates(int num_states);
 
 protected:
     void setValueFromMidi(MidiCategory c, double v);
 
 private:
     bool m_bIsToggleButton;
+    int m_iNoStates;
 };
 
 #endif
