@@ -26,6 +26,7 @@ class QWidget;
 class ControlObjectThreadMain;
 class ControlPotmeter;
 class SkinLoader;
+class PlayerManager;
 
 /**
   *@author Tue & Ken Haste Andersen
@@ -35,7 +36,8 @@ class DlgPrefControls : public QWidget, public Ui::DlgPrefControlsDlg  {
     Q_OBJECT
 public:
     DlgPrefControls(QWidget *parent, MixxxApp *mixxx,
-                    SkinLoader* pSkinLoader, ConfigObject<ConfigValue> *pConfig);
+                    SkinLoader* pSkinLoader, PlayerManager* pPlayerManager,
+                    ConfigObject<ConfigValue> *pConfig);
     ~DlgPrefControls();
 public slots:
     void slotUpdate();
@@ -52,6 +54,7 @@ public slots:
     void slotUpdateSchemes();
     void slotSetPositionDisplay(int);
     void slotSetPositionDisplay(double);
+    void slotSetAllowTrackLoadToPlayingDeck(int);
     void slotSetCueDefault(int);
     void slotSetCueRecall(int);
     void slotSetRateRamp(bool);
@@ -60,13 +63,12 @@ public slots:
 private:
     /** Pointer to ConfigObject */
     ConfigObject<ConfigValue> *m_pConfig;
-    /** Pointers to ControlObjects associated with rate sliders */
-    ControlObjectThreadMain *m_pControlRate1, *m_pControlRate2, *m_pControlRateRange1, *m_pControlRateRange2;
     ControlObject* m_pControlPositionDisplay;
-    /** Pointer to ControlObjects for controlling direction of rate sliders */
-    ControlObjectThreadMain *m_pControlRateDir1, *m_pControlRateDir2;
-    /** Pointer to ControlObjects for cue behavior */
-    ControlObjectThreadMain *m_pControlCueDefault1, *m_pControlCueDefault2;
+    QList<ControlObjectThreadMain*> m_cueControls;
+    QList<ControlObjectThreadMain*> m_rateControls;
+    QList<ControlObjectThreadMain*> m_rateDirControls;
+    QList<ControlObjectThreadMain*> m_rateRangeControls;
+    PlayerManager* m_pPlayerManager;
     MixxxApp *m_mixxx;
     SkinLoader* m_pSkinLoader;
 };
