@@ -18,6 +18,8 @@
 
 #ifdef __VINYLCONTROL__
 #include "dlgprefvinyl.h"
+#else
+#include "dlgprefnovinyl.h"
 #endif
 
 #ifdef __SHOUTCAST__
@@ -45,10 +47,12 @@
 #include <QDialog>
 #include <QtGui>
 #include <QEvent>
+#include <QScrollArea>
 
 DlgPreferences::DlgPreferences(MixxxApp * mixxx, SkinLoader* pSkinLoader,
-                               SoundManager * soundman,
-                               MidiDeviceManager * midi, ConfigObject<ConfigValue> * _config)
+                               SoundManager * soundman, PlayerManager* pPlayerManager,
+                               MidiDeviceManager * midi, VinylControlManager *pVCManager,
+                               ConfigObject<ConfigValue> * _config)
         :  QDialog(), Ui::DlgPreferencesDlg() {
     m_pMixxx = mixxx;
     m_pMidiDeviceManager = midi;
@@ -64,44 +68,42 @@ DlgPreferences::DlgPreferences(MixxxApp * mixxx, SkinLoader* pSkinLoader,
     createIcons();
     //contentsTreeWidget->setCurrentRow(0);
 
-    // Construct widgets for use in tabs
-    wsound = new DlgPrefSound(this, soundman, config);
-    wplaylist = new DlgPrefPlaylist(this, config);
-    wcontrols = new DlgPrefControls(this, mixxx, pSkinLoader, config);
-    weq = new DlgPrefEQ(this, config);
-    wcrossfader = new DlgPrefCrossfader(this, config);
-    wbpm = new DlgPrefBpm(this, config);
-    wreplaygain = new DlgPrefReplayGain(this, config);
-    wrecord = new DlgPrefRecord(this, config);
-#ifdef __VINYLCONTROL__
-    wvinylcontrol = new DlgPrefVinyl(this, soundman, config);
-#endif
-#ifdef __SHOUTCAST__
-    wshoutcast = new DlgPrefShoutcast(this, config);
-#endif
-    wNoMidi = new DlgPrefNoMidi(this, config);
-
     while (pagesWidget->count() > 0)
     {
         pagesWidget->removeWidget(pagesWidget->currentWidget());
     }
+    m_pageSizeHint = QSize(0,0);
 
-    pagesWidget->addWidget(wsound);
-    pagesWidget->addWidget(wplaylist);
-    pagesWidget->addWidget(wcontrols);
-    pagesWidget->addWidget(weq);
-    pagesWidget->addWidget(wcrossfader);
-    pagesWidget->addWidget(wrecord);
-    pagesWidget->addWidget(wbpm);
-    pagesWidget->addWidget(wreplaygain);
+    // Construct widgets for use in tabs
+    m_wsound = new DlgPrefSound(this, soundman, pPlayerManager, config);
+    addPageWidget(m_wsound);
+    m_wplaylist = new DlgPrefPlaylist(this, config);
+    addPageWidget(m_wplaylist);
+    m_wcontrols = new DlgPrefControls(this, mixxx, pSkinLoader, pPlayerManager, config);
+    addPageWidget(m_wcontrols);
+    m_weq = new DlgPrefEQ(this, config);
+    addPageWidget(m_weq);
+    m_wcrossfader = new DlgPrefCrossfader(this, config);
+    addPageWidget(m_wcrossfader);
+    m_wbpm = new DlgPrefBpm(this, config);
+    addPageWidget(m_wbpm);
+    m_wreplaygain = new DlgPrefReplayGain(this, config);
+    addPageWidget(m_wreplaygain);
+    m_wrecord = new DlgPrefRecord(this, config);
+    addPageWidget(m_wrecord);
 #ifdef __VINYLCONTROL__
-    pagesWidget->addWidget(wvinylcontrol);
+    m_wvinylcontrol = new DlgPrefVinyl(this, pVCManager, config);
+    addPageWidget(m_wvinylcontrol);
+#else
+    m_wnovinylcontrol = new DlgPrefNoVinyl(this, soundman, config);
+    addPageWidget(m_wnovinylcontrol);
 #endif
 #ifdef __SHOUTCAST__
-    pagesWidget->addWidget(wshoutcast);
+    m_wshoutcast = new DlgPrefShoutcast(this, config);
+    addPageWidget(m_wshoutcast);
 #endif
-
-    pagesWidget->addWidget(wNoMidi);
+    m_wNoMidi = new DlgPrefNoMidi(this, config);
+    addPageWidget(m_wNoMidi);
     setupMidiWidgets();
 
 
@@ -113,41 +115,40 @@ DlgPreferences::DlgPreferences(MixxxApp * mixxx, SkinLoader* pSkinLoader,
     connect(this, SIGNAL(closeDlg()), this,      SLOT(slotHide()));
     connect(m_pMidiDeviceManager, SIGNAL(devicesChanged()), this, SLOT(rescanMidi()));
 
-    connect(this, SIGNAL(showDlg()), wsound,     SLOT(slotUpdate()));
-    connect(this, SIGNAL(showDlg()), wplaylist,  SLOT(slotUpdate()));
-    connect(this, SIGNAL(showDlg()), wcontrols,  SLOT(slotUpdate()));
-    connect(this, SIGNAL(showDlg()), weq,        SLOT(slotUpdate()));
-    connect(this, SIGNAL(showDlg()),wcrossfader, SLOT(slotUpdate()));
-    connect(this, SIGNAL(showDlg()), wbpm,       SLOT(slotUpdate()));
-    connect(this, SIGNAL(showDlg()), wreplaygain,SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wsound,     SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wplaylist,  SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wcontrols,  SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_weq,        SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wcrossfader, SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wbpm,       SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wreplaygain,SLOT(slotUpdate()));
 
-    connect(this, SIGNAL(showDlg()), wrecord,    SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wrecord,    SLOT(slotUpdate()));
 #ifdef __VINYLCONTROL__
-    connect(this, SIGNAL(showDlg()), wvinylcontrol, SLOT(slotShow()));
-    connect(this, SIGNAL(closeDlg()), wvinylcontrol,SLOT(slotClose()));
-    connect(this, SIGNAL(showDlg()), wvinylcontrol,    SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wvinylcontrol, SLOT(slotShow()));
+    connect(this, SIGNAL(closeDlg()), m_wvinylcontrol,SLOT(slotClose()));
+    connect(this, SIGNAL(showDlg()), m_wvinylcontrol,    SLOT(slotUpdate()));
     //connect(ComboBoxSoundApi,             SIGNAL(activated(int)),    this, SLOT(slotApplyApi()));
 #endif
 #ifdef __SHOUTCAST__
-    connect(this, SIGNAL(showDlg()), wshoutcast,SLOT(slotUpdate()));
+    connect(this, SIGNAL(showDlg()), m_wshoutcast,SLOT(slotUpdate()));
 #endif
 
 #ifdef __VINYLCONTROL__
-    connect(wvinylcontrol, SIGNAL(refreshVCProxies()), wsound, SLOT(forceApply()));
-    connect(buttonBox, SIGNAL(accepted()), wvinylcontrol,    SLOT(slotApply())); //It's important for this to be before the
+    connect(buttonBox, SIGNAL(accepted()), m_wvinylcontrol,    SLOT(slotApply())); //It's important for this to be before the
                                                                                  //connect for wsound...
 #endif
-    connect(buttonBox, SIGNAL(accepted()), wsound,    SLOT(slotApply()));
-    connect(buttonBox, SIGNAL(accepted()), wplaylist, SLOT(slotApply()));
-    connect(buttonBox, SIGNAL(accepted()), wcontrols, SLOT(slotApply()));
-    connect(buttonBox, SIGNAL(accepted()), weq,       SLOT(slotApply()));
-    connect(buttonBox, SIGNAL(accepted()),wcrossfader,SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wsound,    SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wplaylist, SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wcontrols, SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_weq,       SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wcrossfader,SLOT(slotApply()));
     connect(buttonBox, SIGNAL(accepted()), this,      SLOT(slotApply()));
-    connect(buttonBox, SIGNAL(accepted()), wbpm,      SLOT(slotApply()));
-    connect(buttonBox, SIGNAL(accepted()),wreplaygain,SLOT(slotApply()));
-    connect(buttonBox, SIGNAL(accepted()), wrecord,   SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wbpm,      SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wreplaygain,SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wrecord,   SLOT(slotApply()));
 #ifdef __SHOUTCAST__
-    connect(buttonBox, SIGNAL(accepted()), wshoutcast,SLOT(slotApply()));
+    connect(buttonBox, SIGNAL(accepted()), m_wshoutcast,SLOT(slotApply()));
 #endif
 
     //Update the library when you change the options
@@ -160,7 +161,7 @@ DlgPreferences::DlgPreferences(MixxxApp * mixxx, SkinLoader* pSkinLoader,
 
 DlgPreferences::~DlgPreferences()
 {
-  destroyMidiWidgets();
+    destroyMidiWidgets();
 }
 
 void DlgPreferences::createIcons()
@@ -170,7 +171,7 @@ void DlgPreferences::createIcons()
     m_pSoundButton->setText(0, tr("Sound Hardware"));
     m_pSoundButton->setTextAlignment(0, Qt::AlignLeft | Qt::AlignVCenter);
     m_pSoundButton->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-    
+
 /*
     QTreeWidgetItem * midiButton = new QTreeWidgetItem(contentsTreeWidget);
     midiButton->setIcon(0, QIcon(":/images/preferences/controllers.png"));
@@ -198,7 +199,7 @@ void DlgPreferences::createIcons()
     m_pPlaylistButton->setTextAlignment(0, Qt::AlignLeft | Qt::AlignVCenter);
     m_pPlaylistButton->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
 
-       m_pControlsButton = new QTreeWidgetItem(contentsTreeWidget, QTreeWidgetItem::Type);
+    m_pControlsButton = new QTreeWidgetItem(contentsTreeWidget, QTreeWidgetItem::Type);
     m_pControlsButton->setIcon(0, QIcon(":/images/preferences/ic_preferences_interface.png"));
     m_pControlsButton->setText(0, tr("Interface"));
     m_pControlsButton->setTextAlignment(0, Qt::AlignLeft | Qt::AlignVCenter);
@@ -242,6 +243,14 @@ void DlgPreferences::createIcons()
     m_pVinylControlButton->setText(0, tr("Vinyl Control"));
     m_pVinylControlButton->setTextAlignment(0, Qt::AlignLeft | Qt::AlignVCenter);
     m_pVinylControlButton->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+#else
+    m_pVinylControlButton = new QTreeWidgetItem(contentsTreeWidget, QTreeWidgetItem::Type);
+    //QT screws up my nice vinyl svg for some reason, so we'll use a PNG version
+    //instead...
+    m_pVinylControlButton->setIcon(0, QIcon(":/images/preferences/ic_preferences_vinyl.png"));
+    m_pVinylControlButton->setText(0, tr("Vinyl Control"));
+    m_pVinylControlButton->setTextAlignment(0, Qt::AlignLeft | Qt::AlignVCenter);
+    m_pVinylControlButton->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
 #endif
 
 #ifdef __SHOUTCAST__
@@ -262,75 +271,67 @@ void DlgPreferences::changePage(QTreeWidgetItem * current, QTreeWidgetItem * pre
         current = previous;
 
     if (current == m_pSoundButton) {
-           wsound->slotUpdate();
-           pagesWidget->setCurrentWidget(wsound);
-       } else if (current == m_pPlaylistButton)
-           pagesWidget->setCurrentWidget(wplaylist);
-       else if (current == m_pControlsButton)
-           pagesWidget->setCurrentWidget(wcontrols);
-       else if (current == m_pEqButton)
-           pagesWidget->setCurrentWidget(weq);
-       else if (current == m_pCrossfaderButton)
-           pagesWidget->setCurrentWidget(wcrossfader);
-       else if (current == m_pRecordingButton)
-           pagesWidget->setCurrentWidget(wrecord);
-       else if (current == m_pBPMdetectButton)
-           pagesWidget->setCurrentWidget(wbpm);
-       else if (current == m_pReplayGainButton)
-    	   pagesWidget->setCurrentWidget(wreplaygain);
+    	m_wsound->slotUpdate();
+    	pagesWidget->setCurrentWidget(m_wsound->parentWidget()->parentWidget());
+    } else if (current == m_pPlaylistButton) {
+    	pagesWidget->setCurrentWidget(m_wplaylist->parentWidget()->parentWidget());
+    } else if (current == m_pControlsButton) {
+    	pagesWidget->setCurrentWidget(m_wcontrols->parentWidget()->parentWidget());
+    } else if (current == m_pEqButton) {
+    	pagesWidget->setCurrentWidget(m_weq->parentWidget()->parentWidget());
+    } else if (current == m_pCrossfaderButton) {
+    	pagesWidget->setCurrentWidget(m_wcrossfader->parentWidget()->parentWidget());
+    } else if (current == m_pRecordingButton) {
+    	pagesWidget->setCurrentWidget(m_wrecord->parentWidget()->parentWidget());
+    } else if (current == m_pBPMdetectButton) {
+    	pagesWidget->setCurrentWidget(m_wbpm->parentWidget()->parentWidget());
+    } else if (current == m_pReplayGainButton) {
+    	pagesWidget->setCurrentWidget(m_wreplaygain->parentWidget()->parentWidget());
 
 #ifdef __VINYLCONTROL__
-       else if (current == m_pVinylControlButton)
-           pagesWidget->setCurrentWidget(wvinylcontrol);
+    } else if (current == m_pVinylControlButton) {
+    	pagesWidget->setCurrentWidget(m_wvinylcontrol->parentWidget()->parentWidget());
+#else
+    } else if (current == m_pVinylControlButton) {
+           pagesWidget->setCurrentWidget(m_wnovinylcontrol->parentWidget()->parentWidget());
 #endif
 #ifdef __SHOUTCAST__
-       else if (current == m_pShoutcastButton)
-           pagesWidget->setCurrentWidget(wshoutcast);
+    } else if (current == m_pShoutcastButton) {
+           pagesWidget->setCurrentWidget(m_wshoutcast->parentWidget()->parentWidget());
 #endif
 
        //Handle selection of midi device items
-       else if (m_midiBindingsButtons.indexOf(current) >= 0)
-       {
-           int index = m_midiBindingsButtons.indexOf(current);
-           pagesWidget->setCurrentWidget(wmidiBindingsForDevice.value(index));
-           //Manually fire this slot since it doesn't work right...
-           wmidiBindingsForDevice.value(index)->slotUpdate();
-       }
+    } else if (m_midiBindingsButtons.indexOf(current) >= 0) {
+    	int index = m_midiBindingsButtons.indexOf(current);
+    	pagesWidget->setCurrentWidget(m_wmidiBindingsForDevice.value(index)->parentWidget()->parentWidget());
+    	//Manually fire this slot since it doesn't work right...
+    	m_wmidiBindingsForDevice.value(index)->slotUpdate();
+    } else if (current == m_pMIDITreeItem) {
+        //If the root "MIDI Device" item is clicked, select the first MIDI device instead.
+        //If there is no first MIDI device, display a page that says so (just so we don't not change the page)
+        if (m_wmidiBindingsForDevice.count() > 0) {
+            //Expand the MIDI subtree
+            contentsTreeWidget->setItemExpanded(m_pMIDITreeItem, true);
 
-       //If the root "MIDI Device" item is clicked, select the first MIDI device instead.
-       //If there is no first MIDI device, display a page that says so (just so we don't not change the page)
-       else if (current == m_pMIDITreeItem)
-       {
-           if (wmidiBindingsForDevice.count() > 0)
-           {
-               //Expand the MIDI subtree
-               contentsTreeWidget->setItemExpanded(m_pMIDITreeItem, true);
-
-               /*
-               * FIXME: None of the following works right, for some reason. - Albert Feb 9/09
-               */
-
-               //Select the first MIDI device
-               //contentsTreeWidget->setItemSelected(m_pMIDITreeItem, false);
-               /*
-               foreach(QTreeWidgetItem* item, contentsTreeWidget->selectedItems())
-               {
-                   contentsTreeWidget->setItemSelected(item, false);
-               }*/
-               //contentsTreeWidget->setItemSelected(m_midiBindingsButtons.value(0), true);
-
-           }
-           else
-           {
-               pagesWidget->setCurrentWidget(wNoMidi);
-           }
-       }
+            // FIXME: None of the following works right, for some reason. - Albert Feb 9/09
 
+            //Select the first MIDI device
+            //contentsTreeWidget->setItemSelected(m_pMIDITreeItem, false);
+            /*
+              foreach(QTreeWidgetItem* item, contentsTreeWidget->selectedItems())
+              {
+              contentsTreeWidget->setItemSelected(item, false);
+              }*/
+            //contentsTreeWidget->setItemSelected(m_midiBindingsButtons.value(0), true);
+        } else {
+            pagesWidget->setCurrentWidget(m_wNoMidi->parentWidget()->parentWidget());
+        }
+    }
 }
 
 void DlgPreferences::showSoundHardwarePage()
 {
-    pagesWidget->setCurrentWidget(wsound);
+    pagesWidget->setCurrentWidget(m_wsound->parentWidget()->parentWidget());
     contentsTreeWidget->setCurrentItem(m_pSoundButton);
 }
 
@@ -354,34 +355,58 @@ void DlgPreferences::slotHide()
 
 void DlgPreferences::slotShow()
 {
-  //m_pMixxx->releaseKeyboard();
+    //m_pMixxx->releaseKeyboard();
+
+    QSize optimumSize;
+    QSize deltaSize;
+    QSize pagesSize;
+    QSize saSize;
+
+    adjustSize();
+
+    optimumSize = qApp->desktop()->availableGeometry(this).size();
+
+    if (frameSize() == size()) {
+        // This code is reached in Gnome 2.3
+        qDebug() << "guess the size of the window decoration";
+        optimumSize -= QSize(2,30);
+    } else {
+        optimumSize -= (frameSize() - size());
+    }
+
+    QSize staticSize = size() - pagesWidget->size();
+    optimumSize = optimumSize.boundedTo(staticSize + m_pageSizeHint);
+
+    QRect optimumRect = geometry();
+    optimumRect.setSize(optimumSize);
+    setGeometry(optimumRect);
 }
 
 void DlgPreferences::rescanMidi()
 {
-  destroyMidiWidgets();
-  setupMidiWidgets();
+    destroyMidiWidgets();
+    setupMidiWidgets();
 }
 
 void DlgPreferences::destroyMidiWidgets()
 {
-//XXX this, and the corresponding code over in onShow(), is pretty bad and messy; it should be wrapped up in a class so that constructors and destructors can handle this setup/teardown
+    //XXX this, and the corresponding code over in onShow(), is pretty bad and messy; it should be wrapped up in a class so that constructors and destructors can handle this setup/teardown
 
-  m_midiBindingsButtons.clear();
+    m_midiBindingsButtons.clear();
 
-  while (!wmidiBindingsForDevice.isEmpty())
+    while (!m_wmidiBindingsForDevice.isEmpty())
     {
-      DlgPrefMidiBindings* midiDlg = wmidiBindingsForDevice.takeLast();
-      pagesWidget->removeWidget(midiDlg);
-      delete midiDlg;
+        DlgPrefMidiBindings* midiDlg = m_wmidiBindingsForDevice.takeLast();
+        pagesWidget->removeWidget(midiDlg);
+        delete midiDlg;
     }
 
-  while(m_pMIDITreeItem->childCount() > 0)
+    while(m_pMIDITreeItem->childCount() > 0)
     {
-      QTreeWidgetItem* midiBindingsButton = m_pMIDITreeItem->takeChild(0);
-      //qDebug() << " Q|T|r\e\eWidgetItem point is " << midiBindingsButton;
-      m_pMIDITreeItem->removeChild(midiBindingsButton);
-      delete midiBindingsButton;
+        QTreeWidgetItem* midiBindingsButton = m_pMIDITreeItem->takeChild(0);
+        //qDebug() << " Q|T|r\e\eWidgetItem point is " << midiBindingsButton;
+        m_pMIDITreeItem->removeChild(midiBindingsButton);
+        delete midiBindingsButton;
     }
 }
 
@@ -392,13 +417,13 @@ void DlgPreferences::setupMidiWidgets()
     QListIterator<MidiDevice*> it(deviceList);
 
     while (it.hasNext())
-      {
+    {
         MidiDevice* currentDevice = it.next();
         QString curDeviceName = currentDevice->getName();
         //qDebug() << "curDeviceName: " << curDeviceName;
         DlgPrefMidiBindings* midiDlg = new DlgPrefMidiBindings(this, currentDevice, m_pMidiDeviceManager, config);
-        wmidiBindingsForDevice.append(midiDlg);
-        pagesWidget->addWidget(midiDlg);
+        m_wmidiBindingsForDevice.append(midiDlg);
+        addPageWidget(midiDlg);
         connect(this, SIGNAL(showDlg()), midiDlg, SLOT(slotUpdate()));
         connect(buttonBox, SIGNAL(accepted()), midiDlg, SLOT(slotApply()));
         connect(midiDlg, SIGNAL(deviceStateChanged(DlgPrefMidiBindings*,bool)), this, SLOT(slotHighlightDevice(DlgPrefMidiBindings*,bool)));
@@ -417,20 +442,37 @@ void DlgPreferences::setupMidiWidgets()
         if (currentDevice->isOpen()) temp.setBold(true);
         else temp.setBold(false);
         midiBindingsButton->setFont(0,temp);
-      }
+    }
 }
 
 void DlgPreferences::slotApply()
 {
     m_pMidiDeviceManager->saveMappings();
-//    m_pMixxx->grabKeyboard();
+    //m_pMixxx->grabKeyboard();
 }
 
 void DlgPreferences::slotHighlightDevice(DlgPrefMidiBindings* dialog, bool enabled)
 {
-    QTreeWidgetItem * midiBindingsButton = m_midiBindingsButtons.at(wmidiBindingsForDevice.indexOf(dialog));
+    QTreeWidgetItem* midiBindingsButton = m_midiBindingsButtons.at(m_wmidiBindingsForDevice.indexOf(dialog));
     QFont temp = midiBindingsButton->font(0);
     if (enabled) temp.setBold(true);
     else temp.setBold(false);
     midiBindingsButton->setFont(0,temp);
 }
+
+int DlgPreferences::addPageWidget(QWidget* w) {
+    int iret;
+
+    QScrollArea* sa = new QScrollArea(pagesWidget);
+    sa->setWidgetResizable(true);
+
+    sa->setWidget(w);
+    iret = pagesWidget->addWidget(sa);
+
+    int iframe = 2 * sa->frameWidth();
+    m_pageSizeHint = m_pageSizeHint.expandedTo(w->sizeHint()+QSize(iframe, iframe));
+
+    return iret;
+}
+
+
