@@ -27,9 +27,13 @@ CueControl::CueControl(const char * _group,
         m_bHotcueCancel(false) {
     createControls();
 
-
     m_pTrackSamples = ControlObject::getControl(ConfigKey(_group, "track_samples"));
 
+    m_pQuantizeEnabled = ControlObject::getControl(ConfigKey(_group, "quantize"));
+
+    m_pNextBeat = ControlObject::getControl(ConfigKey(_group, "beat_next"));
+    m_pClosestBeat = ControlObject::getControl(ConfigKey(_group, "beat_closest"));
+
     m_pCuePoint = new ControlObject(ConfigKey(_group, "cue_point"));
     m_pCueMode = new ControlObject(ConfigKey(_group,"cue_mode"));
     m_pCuePoint->set(-1);
@@ -73,11 +77,22 @@ CueControl::CueControl(const char * _group,
     connect(m_pPlayButton, SIGNAL(valueChanged(double)),
             this, SLOT(cuePlay(double)),
             Qt::DirectConnection);
-
-
 }
 
 CueControl::~CueControl() {
+    delete m_pCuePoint;
+    delete m_pCueMode;
+    delete m_pCueSet;
+    delete m_pCueGoto;
+    delete m_pCueGotoAndStop;
+    delete m_pCueSimple;
+    delete m_pCuePreview;
+    delete m_pCueCDJ;
+    delete m_pCueDefault;
+    while (m_hotcueControl.size() > 0) {
+        HotcueControl* pControl = m_hotcueControl.takeLast();
+        delete pControl;
+    }
 }
 
 void CueControl::createControls() {
@@ -285,12 +300,26 @@ void CueControl::hotcueSet(HotcueControl* pControl, double v) {
     int hotcue = pControl->getHotcueNumber();
     detachCue(hotcue);
     Cue* pCue = m_pLoadedTrack->addCue();
-    pCue->setPosition(getCurrentSample());
+    double cuePosition =
+            (m_pQuantizeEnabled->get() > 0.0 && m_pClosestBeat->get() != -1) ?
+            floorf(m_pClosestBeat->get()) : floorf(getCurrentSample());
+    if (!even(cuePosition))
+        cuePosition--;
+    pCue->setPosition(cuePosition);
     pCue->setHotCue(hotcue);
     pCue->setLabel("");
     pCue->setType(Cue::CUE);
     // TODO(XXX) deal with spurious signals
     attachCue(pCue, hotcue);
+
+    // If quantize is enabled and we are not playing, jump to the cue point
+    // since it's not necessarily where we currently are. TODO(XXX) is this
+    // potentially invalid for vinyl control?
+    bool playing = m_pPlayButton->get() > 0;
+    if (!playing && m_pQuantizeEnabled->get() > 0.0) {
+        lock.unlock();  // prevent deadlock.
+        emit(seekAbs(cuePosition));
+    }
 }
 
 void CueControl::hotcueGoto(HotcueControl* pControl, double v) {
@@ -510,8 +539,9 @@ void CueControl::cueSet(double v) {
         return;
 
     QMutexLocker lock(&m_mutex);
-    double cue = math_max(0.,round(getCurrentSample()));
-    if (!even((int)cue))
+    double cue = (m_pQuantizeEnabled->get() > 0.0 && m_pClosestBeat->get() != -1) ?
+            floorf(m_pClosestBeat->get()) : floorf(getCurrentSample());
+    if (!even(cue))
         cue--;
     m_pCuePoint->set(cue);
     saveCuePoint(cue);
@@ -595,7 +625,7 @@ void CueControl::cueSimple(double v) {
 
 void CueControl::cueCDJ(double v) {
     /* This is how CDJ cue buttons work:
-     * If pressed while playing, stop playback at go to cue.
+     * If pressed while playing, stop playback and go to cue.
      * If pressed while stopped and at cue, play while pressed.
      * If pressed while stopped and not at cue, set new cue point.
      * If play is pressed while holding cue, the deck is now playing. (Handled in cuePlay().)
@@ -624,6 +654,13 @@ void CueControl::cueCDJ(double v) {
                 cueSet(v);
                 // Just in case.
                 m_bPreviewing = false;
+
+                // If quantize is enabled, jump to the cue point since it's not
+                // necessarily where we currently are
+                if (m_pQuantizeEnabled->get() > 0.0) {
+                    lock.unlock();  // prevent deadlock.
+                    emit(seekAbs(m_pCuePoint->get()));
+                }
             }
         }
     } else if (m_bPreviewing) {
@@ -643,15 +680,17 @@ void CueControl::cueCDJ(double v) {
 }
 
 void CueControl::cuePlay(double v) {
+    Q_UNUSED(v);
+    
     QMutexLocker lock(&m_mutex);
 
-    if (m_bPreviewing && !v) {
+    if (m_bPreviewing) {
     // we're previewing? Then stop previewing and go into normal play mode.
         m_pPlayButton->set(1.0);
         m_bPreviewing = false;
     }
 
-    if (m_bPreviewingHotcue && !v) {
+    if (m_bPreviewingHotcue) {
         m_pPlayButton->set(1.0);
         m_bHotcueCancel = true;
     }
@@ -723,6 +762,14 @@ HotcueControl::HotcueControl(const char* pGroup, int i)
 }
 
 HotcueControl::~HotcueControl() {
+    delete m_hotcuePosition;
+    delete m_hotcueEnabled;
+    delete m_hotcueSet;
+    delete m_hotcueGoto;
+    delete m_hotcueGotoAndStop;
+    delete m_hotcueActivate;
+    delete m_hotcueActivatePreview;
+    delete m_hotcueClear;
 }
 
 void HotcueControl::slotHotcueSet(double v) {
