@@ -24,6 +24,9 @@
 #include "sampleutil.h"
 #include <time.h>   // for clock() and CLOCKS_PER_SEC
 
+ControlPotmeter* EnginePregain::s_pReplayGainBoost = NULL;
+ControlObject* EnginePregain::s_pEnableReplayGain = NULL;
+
 /*----------------------------------------------------------------
    A pregaincontrol is ... a pregain.
    ----------------------------------------------------------------*/
@@ -34,22 +37,14 @@ EnginePregain::EnginePregain(const char * group)
     m_pControlReplayGain = new ControlObject(ConfigKey(group, "replaygain"));
     m_pTotalGain = new ControlObject(ConfigKey(group, "total_gain"));
 
-
-    if(ControlObject::getControl(ConfigKey("[ReplayGain]", "InitialReplayGainBoost"))==NULL)
-    {
-        m_pReplayGainBoost = new ControlPotmeter(ConfigKey("[ReplayGain]", "InitialReplayGainBoost"),0., 15.);
-        m_pEnableReplayGain = new ControlObject(ConfigKey("[ReplayGain]", "ReplayGainEnabled"));
-    }
-    else
-    {
-        m_pReplayGainBoost = (ControlPotmeter*)ControlObject::getControl(ConfigKey("[ReplayGain]", "InitialReplayGainBoost"));
-        m_pEnableReplayGain = (ControlObject*)ControlObject::getControl(ConfigKey("[ReplayGain]", "ReplayGainEnabled"));
+    if (s_pReplayGainBoost == NULL) {
+        s_pReplayGainBoost = new ControlPotmeter(ConfigKey("[ReplayGain]", "InitialReplayGainBoost"),0., 15.);
+        s_pEnableReplayGain = new ControlObject(ConfigKey("[ReplayGain]", "ReplayGainEnabled"));
     }
 
     m_bSmoothFade = false;
     m_fClock=0;
     m_fSumClock=0;
-
 }
 
 EnginePregain::~EnginePregain()
@@ -57,13 +52,18 @@ EnginePregain::~EnginePregain()
     delete potmeterPregain;
     delete m_pControlReplayGain;
     delete m_pTotalGain;
+
+    delete s_pEnableReplayGain;
+    s_pEnableReplayGain = NULL;
+    delete s_pReplayGainBoost;
+    s_pReplayGainBoost = NULL;
 }
 
 void EnginePregain::process(const CSAMPLE * pIn, const CSAMPLE * pOut, const int iBufferSize)
 {
 
-    float fEnableReplayGain = m_pEnableReplayGain->get();
-    float fReplayGainBoost = m_pReplayGainBoost->get();
+    float fEnableReplayGain = s_pEnableReplayGain->get();
+    float fReplayGainBoost = s_pReplayGainBoost->get();
     CSAMPLE * pOutput = (CSAMPLE *)pOut;
     float fGain = potmeterPregain->get();
     float fReplayGain = m_pControlReplayGain->get();
@@ -112,7 +112,11 @@ void EnginePregain::process(const CSAMPLE * pIn, const CSAMPLE * pOut, const int
         }
     }
     fGain = fGain*m_fReplayGainCorrection;
-    m_pTotalGain -> set(fGain);
+    m_pTotalGain->set(fGain);
+
+    // Clamp gain to within [0, 2.0] to prevent insane gains. This can happen
+    // (some corrupt files get really high replaygain values).
+    fGain = math_max(0.0, math_min(2.0, fGain));
 
     //qDebug()<<"Clock"<<(float)clock()/CLOCKS_PER_SEC;
     // SampleUtil deals with aliased buffers and gains of 1 or 0.
