@@ -35,8 +35,10 @@ public:
 
 private:
     ControlLogpotmeter *potmeterPregain;
-    ControlPotmeter *m_pReplayGainBoost;
-    ControlObject *m_pControlReplayGain, *m_pEnableReplayGain, *m_pTotalGain;
+    ControlObject *m_pTotalGain;
+    ControlObject* m_pControlReplayGain;
+    static ControlPotmeter *s_pReplayGainBoost;
+    static ControlObject *s_pEnableReplayGain;
     float m_fReplayGainCorrection;
     bool m_bSmoothFade;
     float m_fClock;
