@@ -9,6 +9,7 @@
 
 #include "engine/enginecontrol.h"
 #include "engine/ratecontrol.h"
+#include "engine/positionscratchcontroller.h"
 
 #ifdef _MSC_VER
 #include <float.h>  // for _isnan() on VC++
@@ -37,8 +38,9 @@ RateControl::RateControl(const char* _group,
     m_eRampBackMode(RATERAMP_RAMPBACK_NONE),
     m_dRateTempRampbackChange(0.0),
     m_dOldRate(0.0f),
-    m_pConfig(_config)
-{
+    m_pConfig(_config) {
+    m_pScratchController = new PositionScratchController(_group);
+
     m_pRateDir = new ControlObject(ConfigKey(_group, "rate_dir"));
     m_pRateRange = new ControlObject(ConfigKey(_group, "rateRange"));
     m_pRateSlider = new ControlPotmeter(ConfigKey(_group, "rate"), -1.f, 1.f);
@@ -146,6 +148,18 @@ RateControl::RateControl(const char* _group,
     m_iRateRampSensitivity =
         m_pConfig->getValueString(ConfigKey("[Controls]","RateRampSensitivity")).toInt();
 
+#ifdef __VINYLCONTROL__
+    ControlObject* pVCEnabled = ControlObject::getControl(ConfigKey(_group, "vinylcontrol_enabled"));
+    // Throw a hissy fit if somebody moved us such that the vinylcontrol_enabled
+    // control doesn't exist yet. This will blow up immediately, won't go unnoticed.
+    Q_ASSERT(pVCEnabled);
+    connect(pVCEnabled, SIGNAL(valueChanged(double)),
+            this, SLOT(slotControlVinyl(double)),
+            Qt::DirectConnection);
+    connect(pVCEnabled, SIGNAL(valueChangedFromEngine(double)),
+            this, SLOT(slotControlVinyl(double)),
+            Qt::DirectConnection);
+#endif
 }
 
 RateControl::~RateControl() {
@@ -171,8 +185,10 @@ RateControl::~RateControl() {
     delete m_pWheel;
     delete m_pScratch;
     delete m_pOldScratch;
+    delete m_pScratchToggle;
     delete m_pJog;
     delete m_pJogFilter;
+    delete m_pScratchController;
 }
 
 void RateControl::setRateRamp(bool linearMode)
@@ -330,7 +346,7 @@ double RateControl::getWheelFactor() {
 
 double RateControl::getJogFactor() {
     // FIXME: Sensitivity should be configurable separately?
-    const double jogSensitivity = m_pRateRange->get();
+    const double jogSensitivity = 0.1;  // Nudges during playback
     double jogValue = m_pJog->get();
 
     // Since m_pJog is an accumulator, reset it since we've used its value.
@@ -347,14 +363,16 @@ double RateControl::getJogFactor() {
     return jogFactor;
 }
 
-double RateControl::calculateRate(double baserate, bool paused) {
+double RateControl::calculateRate(double baserate, bool paused, int iSamplesPerBuffer,
+                                  bool* isScratching) {
     double rate = 0.0;
     double wheelFactor = getWheelFactor();
     double jogFactor = getJogFactor();
     bool searching = m_pRateSearch->get() != 0.;
-    bool scratchEnable = m_pScratchToggle->get() != 0;
+    bool scratchEnable = m_pScratchToggle->get() != 0 || m_bVinylControlEnabled;
     double scratchFactor = m_pScratch->get();
     double oldScratchFactor = m_pOldScratch->get(); // Deprecated
+
     // Don't trust values from m_pScratch
     if(isnan(scratchFactor)) {
         scratchFactor = 0.0;
@@ -363,6 +381,16 @@ double RateControl::calculateRate(double baserate, bool paused) {
         oldScratchFactor = 0.0;
     }
 
+    double currentSample = getCurrentSample();
+    m_pScratchController->process(currentSample, paused, iSamplesPerBuffer);
+
+    // If position control is enabled, override scratchFactor
+    if (m_pScratchController->isEnabled()) {
+        scratchEnable = true;
+        scratchFactor = m_pScratchController->getRate();
+        *isScratching = true;
+    }
+
     if (searching) {
         // If searching is in progress, it overrides the playback rate.
         rate = m_pRateSearch->get();
@@ -555,3 +583,12 @@ void RateControl::resetRateTemp(void)
 {
     setRateTemp(0.0);
 }
+
+void RateControl::slotControlVinyl(double toggle)
+{
+    m_bVinylControlEnabled = (bool)toggle;
+}
+
+void RateControl::notifySeek(double playPos) {
+    m_pScratchController->notifySeek(playPos);
+}
