@@ -31,8 +31,8 @@ BaseTrackCache::BaseTrackCache(TrackCollection* pTrackCollection,
           m_columns(columns),
           m_columnsJoined(m_columns.join(",")),
           m_columnIndex(buildReverseIndex(m_columns)),
-          m_bIsCaching(isCaching),
           m_bIndexBuilt(false),
+          m_bIsCaching(isCaching),
           m_pTrackCollection(pTrackCollection),
           m_trackDAO(m_pTrackCollection->getTrackDAO()),
           m_database(m_pTrackCollection->getDatabase()) {
@@ -40,7 +40,8 @@ BaseTrackCache::BaseTrackCache(TrackCollection* pTrackCollection,
                     << "album"
                     << "location"
                     << "comment"
-                    << "title";
+                    << "title"
+                    << "genre";
 
     // Convert all the search column names to their field indexes because we use
     // them a bunch.
@@ -48,8 +49,6 @@ BaseTrackCache::BaseTrackCache(TrackCollection* pTrackCollection,
     for (int i = 0; i < m_searchColumns.size(); ++i) {
         m_searchColumnIndices[i] = m_columnIndex.value(m_searchColumns[i], -1);
     }
-
-    buildIndex();
 }
 
 BaseTrackCache::~BaseTrackCache() {
@@ -162,7 +161,6 @@ bool BaseTrackCache::updateIndexWithQuery(QString queryString) {
         }
     }
 
-    qDebug() << "Columns:" << numColumns << "Rows:" << m_trackInfo.size();
     qDebug() << this << "updateIndexWithQuery took" << timer.elapsed() << "ms";
     return true;
 }
@@ -173,7 +171,7 @@ void BaseTrackCache::buildIndex() {
     }
 
     QString queryString = QString("SELECT %1 FROM %2")
-            .arg(m_columnsJoined).arg(m_tableName);
+            .arg(m_columnsJoined, m_tableName);
 
     if (sDebug) {
         qDebug() << this << "buildIndex query:" << queryString;
@@ -208,10 +206,7 @@ void BaseTrackCache::updateTracksInIndex(QSet<int> trackIds) {
     }
 
     QString queryString = QString("SELECT %1 FROM %2 WHERE %3 in (%4)")
-            .arg(m_columnsJoined)
-            .arg(m_tableName)
-            .arg(m_idColumn)
-            .arg(idStrings.join(","));
+            .arg(m_columnsJoined, m_tableName, m_idColumn, idStrings.join(","));
 
     if (sDebug) {
         qDebug() << this << "updateTracksInIndex update query:" << queryString;
@@ -272,6 +267,11 @@ QVariant BaseTrackCache::getTrackValueForColumn(TrackPointer pTrack, int column)
 QVariant BaseTrackCache::data(int trackId, int column) const {
     QVariant result;
 
+    if (!m_bIndexBuilt) {
+        qDebug() << this << "ERROR index is not built for" << m_tableName;
+        return result;
+    }
+
     // TODO(rryan): allow as an argument
     TrackPointer pTrack;
 
@@ -326,6 +326,10 @@ void BaseTrackCache::filterAndSort(const QSet<int>& trackIds,
                                    QString extraFilter, int sortColumn,
                                    Qt::SortOrder sortOrder,
                                    QHash<int, int>* trackToIndex) {
+    if (!m_bIndexBuilt) {
+        buildIndex();
+    }
+
     QStringList idStrings;
 
     if (sortColumn < 0 || sortColumn >= columnCount()) {
@@ -346,7 +350,7 @@ void BaseTrackCache::filterAndSort(const QSet<int>& trackIds,
     QString filter = filterClause(searchQuery, extraFilter, idStrings);
     QString orderBy = orderByClause(sortColumn, sortOrder);
     QString queryString = QString("SELECT %1 FROM %2 %3 %4")
-            .arg(m_idColumn).arg(m_tableName).arg(filter).arg(orderBy);
+            .arg(m_idColumn, m_tableName, filter, orderBy);
 
     if (sDebug) {
         qDebug() << this << "select() executing:" << queryString;
@@ -477,7 +481,7 @@ QString BaseTrackCache::filterClause(QString query, QString extraFilter,
 
     if (idStrings.size() > 0) {
         queryFragments << QString("%1 in (%2)")
-                .arg(m_idColumn).arg(idStrings.join(","));
+                .arg(m_idColumn, idStrings.join(","));
     }
 
     if (!query.isNull() && query != "") {
@@ -492,7 +496,7 @@ QString BaseTrackCache::filterClause(QString query, QString extraFilter,
 
             QStringList columnFragments;
             foreach (QString column, m_searchColumns) {
-                columnFragments << QString("%1 LIKE %2").arg(column).arg(escapedToken);
+                columnFragments << QString("%1 LIKE %2").arg(column, escapedToken);
             }
             tokenFragments << QString("(%1)").arg(columnFragments.join(" OR "));
         }
@@ -515,7 +519,7 @@ QString BaseTrackCache::orderByClause(int sortColumn,
     // this.
     QSqlQuery query(m_database);
     QString queryString = QString("SELECT %1 FROM %2 LIMIT 1")
-            .arg(m_columnsJoined).arg(m_tableName);
+            .arg(m_columnsJoined, m_tableName);
     query.prepare(queryString);
     query.exec();
 
@@ -532,7 +536,7 @@ QString BaseTrackCache::orderByClause(int sortColumn,
         f.name(), QSqlDriver::FieldName);
 
     s.append(QLatin1String("ORDER BY "));
-    QString sort_field = QString("%1.%2").arg(m_tableName).arg(field);
+    QString sort_field = QString("%1.%2").arg(m_tableName, field);
 
     // If the field is a string, sort using its lowercase form so sort is
     // case-insensitive.
