@@ -30,6 +30,8 @@ class CrateTableModel : public BaseSqlTableModel {
     virtual void removeTrack(const QModelIndex& index);
     virtual void removeTracks(const QModelIndexList& indices);
     virtual bool addTrack(const QModelIndex& index, QString location);
+    // Returns the number of unsuccessful track additions
+    virtual int addTracks(const QModelIndex& index, QList <QString> locations);
     virtual void moveTrack(const QModelIndex& sourceIndex,
                            const QModelIndex& destIndex);
     TrackModel::CapabilitiesFlags getCapabilities() const;
