@@ -354,8 +354,10 @@ void TrackDAO::addTracks(QList<TrackInfoObject*> tracksToAdd, bool unremove) {
     QSqlQuery track_lookup(m_database);
     // Mapping of track library record id to mixxx_deleted field.
     QHash<int, QPair<int, bool> > tracksPresent;
-    track_lookup.prepare("SELECT location, id, mixxx_deleted from library WHERE location IN (" +
-                         trackLocationIds.join(",")+ ")");
+    track_lookup.prepare(
+        QString("SELECT location, id, mixxx_deleted from library WHERE location IN (%1)")
+        .arg(trackLocationIds.join(",")));
+
     if (!track_lookup.exec()) {
         LOG_FAILED_QUERY(track_lookup)
                 << "Failed to lookup existing tracks:";
@@ -452,6 +454,29 @@ int TrackDAO::addTrack(QFileInfo& fileInfo, bool unremove) {
     return trackId;
 }
 
+QList<int> TrackDAO::addTracks(QList<QFileInfo> fileInfoList, bool unremove) {
+    QList<int> trackIDs;
+
+    //create the list of TrackInfoObjects from the fileInfoList
+    QList<TrackInfoObject*> pTrackList;
+    QMutableListIterator<QFileInfo> it(fileInfoList);
+    while (it.hasNext()) {
+        QFileInfo& info = it.next();
+        pTrackList.append(new TrackInfoObject(info));
+    }
+
+    addTracks(pTrackList, unremove);
+
+    foreach (TrackInfoObject* pTrack, pTrackList) {
+        int trackID = pTrack->getId();
+        if (trackID >= 0) {
+            trackIDs.append(trackID);
+        }
+        delete pTrack;
+    }
+    return trackIDs;
+}
+
 int TrackDAO::addTrack(QString absoluteFilePath, bool unremove)
 {
     QFileInfo fileInfo(absoluteFilePath);
@@ -488,19 +513,14 @@ void TrackDAO::removeTrack(int id) {
 }
 
 void TrackDAO::removeTracks(QList<int> ids) {
-    QString idList = "";
-
+    QStringList idList;
     foreach (int id, ids) {
-        idList.append(QString("%1,").arg(id));
-    }
-
-    // Strip the last ,
-    if (idList.count() > 0) {
-        idList.truncate(idList.count() - 1);
+        idList.append(QString::number(id));
     }
 
     QSqlQuery query(m_database);
-    query.prepare(QString("UPDATE library SET mixxx_deleted=1 WHERE id in (%1)").arg(idList));
+    query.prepare(QString("UPDATE library SET mixxx_deleted=1 WHERE id in (%1)")
+                  .arg(idList.join(",")));
     if (!query.exec()) {
         LOG_FAILED_QUERY(query);
     }
@@ -521,7 +541,7 @@ void TrackDAO::unremoveTrack(int trackId) {
     QSqlQuery query(m_database);
     query.prepare("UPDATE library "
                   "SET mixxx_deleted=0 "
-                  "WHERE id = " + QString("%1").arg(trackId));
+                  "WHERE id = " + QString::number(trackId));
     if (!query.exec()) {
         LOG_FAILED_QUERY(query)
                 << "Failed to set track" << trackId << "as undeleted";
@@ -712,8 +732,8 @@ TrackPointer TrackDAO::getTrack(int id, bool cacheOnly) const {
         "FROM Library "
         "INNER JOIN track_locations "
             "ON library.location = track_locations.id "
-        "WHERE library.id=" + QString("%1").arg(id)
-    );
+        "WHERE library.id=:track_id");
+    query.bindValue(":track_id", id);
 
     TrackPointer pTrack;
 
@@ -754,7 +774,7 @@ void TrackDAO::updateTrack(TrackInfoObject* pTrack) {
                   "timesplayed=:timesplayed, played=:played, "
                   "channels=:channels, header_parsed=:header_parsed, "
                   "beats_version=:beats_version, beats=:beats "
-                  "WHERE id="+QString("%1").arg(trackId));
+                  "WHERE id=:track_id");
     query.bindValue(":artist", pTrack->getArtist());
     query.bindValue(":title", pTrack->getTitle());
     query.bindValue(":album", pTrack->getAlbum());
@@ -779,6 +799,7 @@ void TrackDAO::updateTrack(TrackInfoObject* pTrack) {
     query.bindValue(":channels", pTrack->getChannels());
     query.bindValue(":header_parsed", pTrack->getHeaderParsed() ? 1 : 0);
     //query.bindValue(":location", pTrack->getLocation());
+    query.bindValue(":track_id", trackId);
 
     BeatsPointer pBeats = pTrack->getBeats();
     QByteArray* pBeatsBlob = NULL;
@@ -855,18 +876,24 @@ void TrackDAO::markTrackLocationAsVerified(QString location)
     }
 }
 
-void TrackDAO::markTracksInDirectoryAsVerified(QString directory) {
+void TrackDAO::markTracksInDirectoriesAsVerified(QStringList directories) {
     //qDebug() << "TrackDAO::markTracksInDirectoryAsVerified" << QThread::currentThread() << m_database.connectionName();
     //qDebug() << "markTracksInDirectoryAsVerified()" << directory;
 
+    FieldEscaper escaper(m_database);
+    QMutableStringListIterator it(directories);
+    while (it.hasNext()) {
+        it.setValue(escaper.escapeString(it.next()));
+    }
+
     QSqlQuery query(m_database);
-    query.prepare("UPDATE track_locations "
-                  "SET needs_verification=0 "
-                  "WHERE directory=:directory");
-    query.bindValue(":directory", directory);
+    query.prepare(
+        QString("UPDATE track_locations "
+                "SET needs_verification=0 "
+                "WHERE directory IN (%1)").arg(directories.join(",")));
     if (!query.exec()) {
         LOG_FAILED_QUERY(query)
-                << "Couldn't mark tracks in" << directory << " as verified.";
+                << "Couldn't mark tracks in" << directories.size() << "directories as verified.";
     }
 }
 
