@@ -7,6 +7,7 @@
 #include <QStringListModel>
 
 #include "library/libraryfeature.h"
+#include "treeitemmodel.h"
 
 class BaseTrackCache;
 class LibraryTableModel;
@@ -22,26 +23,25 @@ class MixxxLibraryFeature : public LibraryFeature {
 
     QVariant title();
     QIcon getIcon();
-
     bool dropAccept(QUrl url);
     bool dropAcceptChild(const QModelIndex& index, QUrl url);
     bool dragMoveAccept(QUrl url);
     bool dragMoveAcceptChild(const QModelIndex& index, QUrl url);
+    TreeItemModel* getChildModel();
 
-    QAbstractItemModel* getChildModel();
-
-public slots:
+  public slots:
     void activate();
     void activateChild(const QModelIndex& index);
     void onRightClick(const QPoint& globalPos);
     void onRightClickChild(const QPoint& globalPos, QModelIndex index);
+    void onLazyChildExpandation(const QModelIndex& index);
     void refreshLibraryModels();
-private:
+
+  private:
     QSharedPointer<BaseTrackCache> m_pBaseTrackCache;
     LibraryTableModel* m_pLibraryTableModel;
     MissingTableModel* m_pMissingTableModel;
-    QStringListModel m_childModel;
+    TreeItemModel m_childModel;
 };
 
-
 #endif /* MIXXXLIBRARYFEATURE_H */
