@@ -11,7 +11,8 @@ ProxyTrackModel::ProxyTrackModel(QAbstractItemModel* pTrackModel,
         // ProxyTrackModel proxies settings requests to the composed TrackModel,
         // don't initialize its TrackModel with valid parameters.
         : TrackModel(QSqlDatabase(), ""),
-          m_bHandleSearches(bHandleSearches) {
+          m_bHandleSearches(bHandleSearches),
+          m_currentSearch("") {
     m_pTrackModel = dynamic_cast<TrackModel*>(pTrackModel);
     Q_ASSERT(m_pTrackModel && pTrackModel);
     setSourceModel(pTrackModel);
