@@ -30,7 +30,7 @@ class ProxyTrackModel : public QSortFilterProxyModel, public virtual TrackModel
     virtual int getTrackId(const QModelIndex& index) const;
     virtual const QLinkedList<int> getTrackRows(int trackId) const;
     virtual void search(const QString& searchText);
-    virtual const QString currentSearch();
+    virtual const QString currentSearch() const;
     virtual bool isColumnInternal(int column);
     virtual bool isColumnHiddenByDefault(int column);
     virtual void removeTrack(const QModelIndex& index);
