@@ -4,16 +4,17 @@
 #include <QtDebug>
 
 #include "trackcollection.h"
-#include "xmlparse.h"
+
 #include "defs.h"
-#include "soundsourceproxy.h"
-#include "library/schemamanager.h"
-#include "trackinfoobject.h"
 #include "library/librarytablemodel.h"
+#include "library/schemamanager.h"
+#include "soundsourceproxy.h"
+#include "trackinfoobject.h"
+#include "xmlparse.h"
 
 TrackCollection::TrackCollection(ConfigObject<ConfigValue>* pConfig)
         : m_pConfig(pConfig),
-          m_db(QSqlDatabase::addDatabase("QSQLITE")),
+          m_db(QSqlDatabase::addDatabase("QSQLITE")), // defaultConnection
           m_cueDao(m_db),
           m_playlistDao(m_db),
           m_crateDao(m_db),
@@ -21,8 +22,8 @@ TrackCollection::TrackCollection(ConfigObject<ConfigValue>* pConfig)
           m_supportedFileExtensionsRegex(
               SoundSourceProxy::supportedFileExtensionsRegex(),
               Qt::CaseInsensitive) {
-    bCancelLibraryScan = 0;
-    qDebug() << QSqlDatabase::drivers();
+    bCancelLibraryScan = false;
+    qDebug() << "Available QtSQL drivers:" << QSqlDatabase::drivers();
 
     m_db.setHostName("localhost");
     m_db.setDatabaseName(MIXXX_DB_PATH);
@@ -30,77 +31,18 @@ TrackCollection::TrackCollection(ConfigObject<ConfigValue>* pConfig)
     m_db.setPassword("mixxx");
     bool ok = m_db.open();
     qDebug() << __FILE__ << "DB status:" << ok;
-    qDebug() << m_db.lastError();
-
-    //Check for tables and create them if missing
-    if (!checkForTables()) exit(-1);
-
-    QStringList columns;
-    columns << "library." + LIBRARYTABLE_ID
-            << "library." + LIBRARYTABLE_PLAYED
-            << "library." + LIBRARYTABLE_TIMESPLAYED
-            << "library." + LIBRARYTABLE_ARTIST
-            << "library." + LIBRARYTABLE_TITLE
-            << "library." + LIBRARYTABLE_ALBUM
-            << "library." + LIBRARYTABLE_YEAR
-            << "library." + LIBRARYTABLE_DURATION
-            << "library." + LIBRARYTABLE_RATING
-            << "library." + LIBRARYTABLE_GENRE
-            << "library." + LIBRARYTABLE_FILETYPE
-            << "library." + LIBRARYTABLE_TRACKNUMBER
-            << "library." + LIBRARYTABLE_KEY
-            << "library." + LIBRARYTABLE_DATETIMEADDED
-            << "library." + LIBRARYTABLE_BPM
-            << "library." + LIBRARYTABLE_BITRATE
-            << "track_locations.location"
-            << "track_locations.fs_deleted"
-            << "library." + LIBRARYTABLE_COMMENT
-            << "library." + LIBRARYTABLE_MIXXXDELETED;
-
-    QSqlQuery query(m_db);
-    QString queryString = "CREATE TEMPORARY VIEW IF NOT EXISTS library_cache_view AS SELECT "
-            + columns.join(",") +
-            " FROM library INNER JOIN track_locations "
-            "ON library.location = track_locations.id";
-    query.prepare(queryString);
-    if (!query.exec()) {
-        qDebug() << query.executedQuery() << query.lastError();
+    if (m_db.lastError().isValid()) {
+        qDebug() << "Error loading database:" << m_db.lastError();
     }
-
-    // Print out any SQL error, if there was one.
-    if (query.lastError().isValid()) {
-        qDebug() << __FILE__ << __LINE__ << query.lastError();
+    // Check for tables and create them if missing
+    if (!checkForTables()) {
+        // TODO(XXX) something a little more elegant
+        exit(-1);
     }
-
-    // Strip out library. and track_locations.
-    for (QStringList::iterator it = columns.begin();
-         it != columns.end(); ++it) {
-        if (it->startsWith("library.")) {
-            *it = it->replace("library.", "");
-        } else if (it->startsWith("track_locations.")) {
-            *it = it->replace("track_locations.", "");
-        }
-    }
-
-    BaseTrackCache* pBaseTrackCache = new BaseTrackCache(
-        this, "library_cache_view", LIBRARYTABLE_ID, columns, true);
-    connect(&m_trackDao, SIGNAL(trackDirty(int)),
-            pBaseTrackCache, SLOT(slotTrackDirty(int)));
-    connect(&m_trackDao, SIGNAL(trackChanged(int)),
-            pBaseTrackCache, SLOT(slotTrackChanged(int)));
-    connect(&m_trackDao, SIGNAL(trackClean(int)),
-            pBaseTrackCache, SLOT(slotTrackClean(int)));
-    connect(&m_trackDao, SIGNAL(tracksAdded(QSet<int>)),
-            pBaseTrackCache, SLOT(slotTracksAdded(QSet<int>)));
-    connect(&m_trackDao, SIGNAL(tracksRemoved(QSet<int>)),
-            pBaseTrackCache, SLOT(slotTracksRemoved(QSet<int>)));
-
-    addTrackSource(QString("default"),
-                   QSharedPointer<BaseTrackCache>(pBaseTrackCache));
 }
 
-TrackCollection::~TrackCollection()
-{
+TrackCollection::~TrackCollection() {
+    qDebug() << "~TrackCollection()";
     // Save all tracks that haven't been saved yet.
     m_trackDao.saveDirtyTracks();
     // TODO(XXX) Maybe fold saveDirtyTracks into TrackDAO::finish now that it
@@ -112,11 +54,9 @@ TrackCollection::~TrackCollection()
     //transaction when this code is called. If there is, it means we probably
     //aren't committing a transaction somewhere that should be.
     m_db.close();
-    qDebug() << "TrackCollection destroyed";
 }
 
-bool TrackCollection::checkForTables()
-{
+bool TrackCollection::checkForTables() {
     if (!m_db.open()) {
         QMessageBox::critical(0, tr("Cannot open database"),
                               tr("Unable to establish a database connection.\n"
@@ -127,7 +67,7 @@ bool TrackCollection::checkForTables()
         return false;
     }
 
-    int requiredSchemaVersion = 8;
+    int requiredSchemaVersion = 13;
     if (!SchemaManager::upgradeToSchemaVersion(m_pConfig, m_db,
                                                requiredSchemaVersion)) {
         QMessageBox::warning(0, tr("Cannot upgrade database schema"),
@@ -147,20 +87,16 @@ bool TrackCollection::checkForTables()
     return true;
 }
 
-
-QSqlDatabase& TrackCollection::getDatabase()
-{
- 	return m_db;
-  }
-
+QSqlDatabase& TrackCollection::getDatabase() {
+    return m_db;
+}
 
 /** Do a non-recursive import of all the songs in a directory. Does NOT decend into subdirectories.
     @param trackDao The track data access object which provides a connection to the database. We use this parameter in order to make this function callable from separate threads. You need to use a different DB connection for each thread.
     @return true if the scan completed without being cancelled. False if the scan was cancelled part-way through.
 */
 bool TrackCollection::importDirectory(QString directory, TrackDAO &trackDao,
-                                      QList<TrackInfoObject*>& tracksToAdd)
-{
+                                      QList<TrackInfoObject*>& tracksToAdd) {
     //qDebug() << "TrackCollection::importDirectory(" << directory<< ")";
 
     emit(startedLoading());
@@ -185,8 +121,7 @@ bool TrackCollection::importDirectory(QString directory, TrackDAO &trackDao,
         m_libraryScanMutex.lock();
         bool cancel = bCancelLibraryScan;
         m_libraryScanMutex.unlock();
-        if (cancel)
-        {
+        if (cancel) {
             return false;
         }
 
@@ -225,17 +160,13 @@ bool TrackCollection::importDirectory(QString directory, TrackDAO &trackDao,
     return true;
 }
 
-
-
-void TrackCollection::slotCancelLibraryScan()
-{
+void TrackCollection::slotCancelLibraryScan() {
     m_libraryScanMutex.lock();
     bCancelLibraryScan = 1;
     m_libraryScanMutex.unlock();
 }
 
-void TrackCollection::resetLibaryCancellation()
-{
+void TrackCollection::resetLibaryCancellation() {
     m_libraryScanMutex.lock();
     bCancelLibraryScan = 0;
     m_libraryScanMutex.unlock();
@@ -253,12 +184,13 @@ PlaylistDAO& TrackCollection::getPlaylistDAO() {
     return m_playlistDao;
 }
 
-QSharedPointer<BaseTrackCache> TrackCollection::getTrackSource(const QString name) {
+QSharedPointer<BaseTrackCache> TrackCollection::getTrackSource(
+    const QString name) {
     return m_trackSources.value(name, QSharedPointer<BaseTrackCache>());
 }
 
-void TrackCollection::addTrackSource(const QString name,
-                                     QSharedPointer<BaseTrackCache> trackSource) {
+void TrackCollection::addTrackSource(
+    const QString name, QSharedPointer<BaseTrackCache> trackSource) {
     Q_ASSERT(!m_trackSources.contains(name));
     m_trackSources[name] = trackSource;
 }
