@@ -23,6 +23,7 @@
 #include "midimessage.h"
 #include "mixxxcontrol.h"
 #include "controlobject.h"
+#include "midiledhandler.h"
 
 #ifdef __MIDISCRIPT__
 #include "midiscriptengine.h"
@@ -47,6 +48,7 @@ MidiDevice::MidiDevice(MidiMapping* mapping) : QThread()
         m_pMidiMapping = new MidiMapping(this);
     }
 
+    // TODO: Should this be in MidiDeviceManager instead?
     // Get --midiDebug command line option
     QStringList commandLineArgs = QApplication::arguments();
     m_midiDebug = commandLineArgs.contains("--midiDebug", Qt::CaseInsensitive);
@@ -95,6 +97,7 @@ void MidiDevice::shutdown()
 #ifdef __MIDISCRIPT__
     m_pMidiMapping->shutdownScriptEngine();
 #endif
+    MidiLedHandler::destroyHandlers(this);
     setReceiveInhibit(false);
 }
 
@@ -179,7 +182,7 @@ void MidiDevice::receive(MidiStatusByte status, char channel, char control, char
       .arg(QString::number((status & 255)>>4, 16).toUpper())
       .arg(QString::number(control, 16).toUpper().rightJustified(2,'0'))
       .arg(QString::number(value, 16).toUpper().rightJustified(2,'0'));
-    
+
     // some status bytes can have the channel encoded in them. Take out the
     // channel when necessary. We do this because later bits of this
     // function (and perhaps its callchain) assume the channel nibble to be
@@ -232,10 +235,12 @@ void MidiDevice::receive(MidiStatusByte status, char channel, char control, char
 
     ConfigKey configKey(mixxxControl.getControlObjectGroup(), mixxxControl.getControlObjectValue());
 
+    MidiOption currMidiOption = mixxxControl.getMidiOption();
+
 #ifdef __MIDISCRIPT__
     // Custom MixxxScript (QtScript) handler
 
-    if (mixxxControl.getMidiOption() == MIDI_OPT_SCRIPT) {
+    if (currMidiOption == MIDI_OPT_SCRIPT) {
         // qDebug() << "MidiDevice: Calling script function" << configKey.item << "with"
         //          << (int)channel << (int)control <<  (int)value << (int)status;
 
@@ -255,24 +260,26 @@ void MidiDevice::receive(MidiStatusByte status, char channel, char control, char
 
     if (p) //Only pass values on to valid ControlObjects.
     {
-        double newValue;
-       
+        double currMixxxControlValue = p->GetMidiValue();
+
+        double newValue = value;
+
         // compute LSB and MSB for pitch bend messages
         if (status == MIDI_STATUS_PITCH_BEND) {
             unsigned int ivalue;
             ivalue = (value << 7) + control;
 
-            newValue = m_pMidiMapping->ComputeValue(mixxxControl.getMidiOption(), p->GetMidiValue(), ivalue);
+            newValue = m_pMidiMapping->ComputeValue(currMidiOption, currMixxxControlValue, ivalue);
 
             // normalize our value to 0-127
             newValue = (newValue / 0x3FFF) * 0x7F;
-        } else {
-            newValue = m_pMidiMapping->ComputeValue(mixxxControl.getMidiOption(), p->GetMidiValue(), value);
+        } else if (currMidiOption != MIDI_OPT_SOFT_TAKEOVER) {
+            newValue = m_pMidiMapping->ComputeValue(currMidiOption, currMixxxControlValue, value);
         }
 
         // ControlPushButton ControlObjects only accept NOTE_ON, so if the midi
         // mapping is <button> we override the Midi 'status' appropriately.
-        switch (mixxxControl.getMidiOption()) {
+        switch (currMidiOption) {
             case MIDI_OPT_BUTTON:
             case MIDI_OPT_SWITCH: status = MIDI_STATUS_NOTE_ON; break; // Buttons and Switches are
                                                                        // treated the same, except
@@ -281,6 +288,12 @@ void MidiDevice::receive(MidiStatusByte status, char channel, char control, char
             default: break;
         }
 
+        // Soft-takeover is processed in addition to any other options
+        if (currMidiOption == MIDI_OPT_SOFT_TAKEOVER) {
+            m_st.enable(mixxxControl);  // This is the only place to enable it if it isn't already.
+            if (m_st.ignore(mixxxControl,newValue,true)) return;
+        }
+
         ControlObject::sync();
 
         //Super dangerous cast here... Should be fine once MidiCategory is replaced with MidiStatusByte permanently.
@@ -345,11 +358,9 @@ void MidiDevice::receive(const unsigned char data[], unsigned int length) {
 }
 #endif
 
-bool MidiDevice::midiDebugging()
-{
-    //Assumes a lock is already held. :/
-    bool debug = m_midiDebug;
-    return debug;
+bool MidiDevice::midiDebugging() {
+    // Assumes a lock is already held. :/
+    return m_midiDebug;
 }
 
 void MidiDevice::setReceiveInhibit(bool inhibit)
