@@ -72,7 +72,8 @@ MidiMapping::MidiMapping(MidiDevice* outputMidiDevice)
 }
 
 MidiMapping::~MidiMapping() {
-
+    delete m_pMidiInputMappingTableModel;
+    delete m_pMidiOutputMappingTableModel;
 }
 
 #ifdef __MIDISCRIPT__
@@ -732,7 +733,7 @@ void MidiMapping::applyPreset() {
         scriptFunctions = m_pScriptEngine->getScriptFunctions();
     }
     if (scriptFunctions.isEmpty()) loadScriptCode();
-
+    
     initializeScripts();
 #endif
 
@@ -753,6 +754,7 @@ void MidiMapping::applyPreset() {
             // Next device
             controller = controller.nextSiblingElement("controller");
         }
+        MidiLedHandler::updateAll();
     }
 }
 
@@ -858,6 +860,7 @@ void MidiMapping::clearPreset() {
         outputs.appendChild(outputNode);
     }
 
+    m_Bindings = doc.documentElement();
     return doc;
 }
 
@@ -946,11 +949,11 @@ void MidiMapping::addOutput(QDomElement &output, QString device) {
 
 bool MidiMapping::addInputControl(MidiStatusByte midiStatus, int midiNo, int midiChannel,
                                   QString controlObjectGroup, QString controlObjectKey,
-                                  MidiOption midiOption)
+                                  QString controlObjectDescription, MidiOption midiOption)
 {
     return addInputControl(MidiMessage(midiStatus, midiNo, midiChannel),
                            MixxxControl(controlObjectGroup, controlObjectKey,
-                                        midiOption));
+                                        controlObjectDescription, midiOption));
 }
 
 bool MidiMapping::addInputControl(MidiMessage message, MixxxControl control)
@@ -1159,9 +1162,10 @@ void MidiMapping::restartScriptEngine()
 void MidiMapping::reset() {
 #ifdef __MIDISCRIPT__   // Can't ifdef slots in the .h file, so we just do the body.
     restartScriptEngine();
-    MidiLedHandler::destroyHandlers();
-    applyPreset();
 #endif
+    MidiLedHandler::destroyHandlers(m_pOutputMidiDevice);
+
+    applyPreset();
 }
 
 void MidiMapping::slotScriptEngineReady() {
