@@ -146,28 +146,38 @@ MixxxApp::MixxxApp(QApplication *a, struct CmdlineArgs args)
         locale = QLocale::system().name();
     }
 
-    // Load Qt translations for this locale
+    // Load Qt translations for this locale from the system translation
+    // path. This is the lowest precedence QTranslator.
     QTranslator* qtTranslator = new QTranslator(a);
-   if( qtTranslator->load("qt_" + locale,
-           QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
-       a->installTranslator(qtTranslator);
-   }
-   else{
-       delete qtTranslator;
-   }
+    if (qtTranslator->load("qt_" + locale,
+                          QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
+        a->installTranslator(qtTranslator);
+    } else {
+        delete qtTranslator;
+    }
 
-    // Load Mixxx specific translations for this locale
+    // Load Qt translations for this locale from the Mixxx translations
+    // folder.
+    QTranslator* mixxxQtTranslator = new QTranslator(a);
+    if (mixxxQtTranslator->load("qt_" + locale, translationsFolder)) {
+        a->installTranslator(mixxxQtTranslator);
+    } else {
+        delete mixxxQtTranslator;
+    }
+
+    // Load Mixxx specific translations for this locale from the Mixxx
+    // translations folder.
     QTranslator* mixxxTranslator = new QTranslator(a);
-    bool mixxxLoaded = mixxxTranslator->load("mixxx_" + locale, translationsFolder);
+    bool mixxxLoaded = mixxxTranslator->load("mixxx_" + locale,
+                                             translationsFolder);
     qDebug() << "Loading translations for locale" << locale
-            << "from translations folder" << translationsFolder << ":"
-            << (mixxxLoaded ? "success" : "fail");
-   if (mixxxLoaded) {
-       a->installTranslator(mixxxTranslator);
-   }
-   else {
-       delete mixxxTranslator;
-   }
+             << "from translations folder" << translationsFolder << ":"
+             << (mixxxLoaded ? "success" : "fail");
+    if (mixxxLoaded) {
+        a->installTranslator(mixxxTranslator);
+    } else {
+        delete mixxxTranslator;
+    }
 
 #ifdef __C_METRICS__
     // Initialize Case Metrics if User is OK with that
@@ -794,11 +804,11 @@ int MixxxApp::noOutputDlg(bool *continueClicked)
 /** initializes all QActions of the application */
 void MixxxApp::initActions()
 {
-    m_pFileLoadSongPlayer1 = new QAction(tr("&Load Song (Player 1)..."), this);
+    m_pFileLoadSongPlayer1 = new QAction(tr("Load Song (Player &1)..."), this);
     m_pFileLoadSongPlayer1->setShortcut(tr("Ctrl+O"));
     m_pFileLoadSongPlayer1->setShortcutContext(Qt::ApplicationShortcut);
 
-    m_pFileLoadSongPlayer2 = new QAction(tr("&Load Song (Player 2)..."), this);
+    m_pFileLoadSongPlayer2 = new QAction(tr("Load Song (Player &2)..."), this);
     m_pFileLoadSongPlayer2->setShortcut(tr("Ctrl+Shift+O"));
     m_pFileLoadSongPlayer2->setShortcutContext(Qt::ApplicationShortcut);
 
@@ -825,7 +835,7 @@ void MixxxApp::initActions()
     m_pOptionsFullScreen = new QAction(tr("&Full Screen"), this);
 
 #ifdef __APPLE__
-    m_pOptionsFullScreen->setShortcut(tr("Ctrl+F"));
+    m_pOptionsFullScreen->setShortcut(tr("Ctrl+Shift+F"));
 #else
     m_pOptionsFullScreen->setShortcut(tr("F11"));
 #endif
@@ -845,17 +855,17 @@ void MixxxApp::initActions()
     m_pHelpTranslation = new QAction(tr("&Translate this application"), this);
 
 #ifdef __VINYLCONTROL__
-    m_pOptionsVinylControl = new QAction(tr("Enable &Vinyl Control 1"), this);
+    m_pOptionsVinylControl = new QAction(tr("Enable Vinyl Control &1"), this);
     m_pOptionsVinylControl->setShortcut(tr("Ctrl+Y"));
     m_pOptionsVinylControl->setShortcutContext(Qt::ApplicationShortcut);
 
-    m_pOptionsVinylControl2 = new QAction(tr("Enable &Vinyl Control 2"), this);
+    m_pOptionsVinylControl2 = new QAction(tr("Enable Vinyl Control &2"), this);
     m_pOptionsVinylControl2->setShortcut(tr("Ctrl+U"));
     m_pOptionsVinylControl2->setShortcutContext(Qt::ApplicationShortcut);
 #endif
 
 #ifdef __SHOUTCAST__
-    m_pOptionsShoutcast = new QAction(tr("Enable live broadcasting"), this);
+    m_pOptionsShoutcast = new QAction(tr("Enable live &broadcasting"), this);
     m_pOptionsShoutcast->setShortcut(tr("Ctrl+L"));
     m_pOptionsShoutcast->setShortcutContext(Qt::ApplicationShortcut);
 #endif
@@ -1311,8 +1321,14 @@ void MixxxApp::slotHelpAbout() {
     }
     about->version_label->setText(version.join(" "));
 
+    QString s_devTeam=QString(tr("Mixxx %1 Development Team")).arg(VERSION);
+    QString s_contributions=tr("With contributions from:");
+    QString s_specialThanks=tr("And special thanks to:");
+    QString s_pastDevs=tr("Past Developers");
+    QString s_pastContribs=tr("Past Contributors");
+
     QString credits =
-    QString("<p align=\"center\"><b>Mixxx %1 Development Team</b></p>"
+    QString("<p align=\"center\"><b>%1</b></p>"
 "<p align=\"center\">"
 "Adam Davison<br>"
 "Albert Santoni<br>"
@@ -1325,9 +1341,10 @@ void MixxxApp::slotHelpAbout() {
 "Bill Good<br>"
 "Owen Williams<br>"
 "Vittorio Colao<br>"
+"Daniel Sch&uuml;rmann<br>"
 
 "</p>"
-"<p align=\"center\"><b>With contributions from:</b></p>"
+"<p align=\"center\"><b>%2</b></p>"
 "<p align=\"center\">"
 "Mark Hills<br>"
 "Andre Roth<br>"
@@ -1373,9 +1390,12 @@ void MixxxApp::slotHelpAbout() {
 "Jens Nachtigall<br>"
 "Scott Ullrich<br>"
 "Jonas &Aring;dahl<br>"
+"Maxime Bochon<br>"
+"Akash Shetye<br>"
+"Ben Clark<br>"
 
 "</p>"
-"<p align=\"center\"><b>And special thanks to:</b></p>"
+"<p align=\"center\"><b>%3</b></p>"
 "<p align=\"center\">"
 "Vestax<br>"
 "Stanton<br>"
@@ -1393,7 +1413,7 @@ void MixxxApp::slotHelpAbout() {
 "Joseph Mattiello<br>"
 "</p>"
 
-"<p align=\"center\"><b>Past Developers</b></p>"
+"<p align=\"center\"><b>%4</b></p>"
 "<p align=\"center\">"
 "Tue Haste Andersen<br>"
 "Ken Haste Andersen<br>"
@@ -1413,7 +1433,7 @@ void MixxxApp::slotHelpAbout() {
 "Ryan Baker<br>"
 "</p>"
 
-"<p align=\"center\"><b>Past Contributors</b></p>"
+"<p align=\"center\"><b>%5</b></p>"
 "<p align=\"center\">"
 "Ludek Hor&#225;cek<br>"
 "Svein Magne Bang<br>"
@@ -1447,7 +1467,7 @@ void MixxxApp::slotHelpAbout() {
 "Michael Pujos<br>"
 "Claudio Bantaloukas<br>"
 "Pavol Rusnak<br>"
-    "</p>").arg(VERSION);
+    "</p>").arg(s_devTeam,s_contributions,s_specialThanks,s_pastDevs,s_pastContribs);
 
     about->textBrowser->setHtml(credits);
     about->show();
@@ -1636,7 +1656,9 @@ void MixxxApp::checkDirectRendering() {
 
 bool MixxxApp::confirmExit() {
     bool playing(false);
+    bool playingSampler(false);
     unsigned int deckCount = m_pPlayerManager->numDecks();
+    unsigned int samplerCount = m_pPlayerManager->numSamplers();
     for (unsigned int i = 0; i < deckCount; ++i) {
         ControlObject *pPlayCO(
             ControlObject::getControl(
@@ -1648,6 +1670,17 @@ bool MixxxApp::confirmExit() {
             break;
         }
     }
+    for (unsigned int i = 0; i < samplerCount; ++i) {
+        ControlObject *pPlayCO(
+            ControlObject::getControl(
+                ConfigKey(QString("[Sampler%1]").arg(i + 1), "play")
+            )
+        );
+        if (pPlayCO && pPlayCO->get()) {
+            playingSampler = true;
+            break;
+        }
+    }
     if (playing) {
         QMessageBox::StandardButton btn = QMessageBox::question(this,
             tr("Confirm Exit"),
@@ -1656,6 +1689,14 @@ bool MixxxApp::confirmExit() {
         if (btn == QMessageBox::No) {
             return false;
         }
+    } else if (playingSampler) {
+        QMessageBox::StandardButton btn = QMessageBox::question(this,
+            tr("Confirm Exit"),
+            tr("A sampler is currently playing. Exit Mixxx?"),
+            QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
+        if (btn == QMessageBox::No) {
+            return false;
+        }
     }
     return true;
 }
