@@ -27,10 +27,11 @@
 #include "defs.h"
 #include <QString>
 
-#define MIXXX_SOUNDSOURCE_API_VERSION 2
+#define MIXXX_SOUNDSOURCE_API_VERSION 3
 /** @note SoundSource API Version history:
            1 - Mixxx 1.8.0 Beta 2
            2 - Mixxx 1.9.0 Pre (added key code)
+           3 - Mixxx 1.10.0 Pre (added freeing function for extensions)
   */
 
 /** Getter function to be declared by all SoundSource plugins */
@@ -40,6 +41,8 @@ namespace Mixxx {
 typedef Mixxx::SoundSource* (*getSoundSourceFunc)(QString filename);
 typedef char** (*getSupportedFileExtensionsFunc)();
 typedef int (*getSoundSourceAPIVersionFunc)();
+/* New in version 3 */
+typedef void (*freeFileExtensionsFunc)(char** exts);
 
 
 /*
