@@ -225,10 +225,23 @@ unsigned SoundSourceOggVorbis::read(volatile unsigned long size, const SAMPLE *
 /*
    Parse the the file to get metadata
  */
-int SoundSourceOggVorbis::parseHeader()
-{
+int SoundSourceOggVorbis::parseHeader() {
     setType("ogg");
-    TagLib::Ogg::Vorbis::File f(getFilename().toUtf8().constData());
+
+#ifdef __WINDOWS__
+    /* From Tobias: A Utf-8 string did not work on my Windows XP (German edition)
+     * If you try this conversion, f.isValid() will return false in many cases
+     * and processTaglibFile() will fail
+     *
+     * The method toLocal8Bit() returns the local 8-bit representation of the string as a QByteArray.
+     * The returned byte array is undefined if the string contains characters not supported
+     * by the local 8-bit encoding.
+     */
+    QByteArray qBAFilename = m_qFilename.toLocal8Bit();
+#else
+    QByteArray qBAFilename = m_qFilename.toUtf8();
+#endif
+    TagLib::Ogg::Vorbis::File f(qBAFilename.constData());
 
     // Takes care of all the default metadata
     bool result = processTaglibFile(f);
