@@ -28,7 +28,7 @@
 #include <QWeakPointer>
 
 #include "defs.h"
-
+#include "track/beats.h"
 #include "library/dao/cue.h"
 
 class QString;
@@ -244,6 +244,12 @@ public:
     /** Set the track's full file path */
     void setLocation(QString location);
 
+    // Get the track's Beats list
+    BeatsPointer getBeats() const;
+
+    // Set the track's Beats
+    void setBeats(BeatsPointer beats);
+
     const Segmentation<QString>* getChordData();
     void setChordData(Segmentation<QString> cd);
 
@@ -253,6 +259,7 @@ public:
   signals:
     void wavesummaryUpdated(TrackInfoObject*);
     void bpmUpdated(double bpm);
+    void beatsUpdated();
     void ReplayGainUpdated(double replaygain);
     void cuesUpdated();
     void changed(TrackInfoObject* pTrack);
@@ -260,6 +267,9 @@ public:
     void clean(TrackInfoObject* pTrack);
     void save(TrackInfoObject* pTrack);
 
+  private slots:
+    void slotBeatsUpdated();
+
   private:
 
     // Common initialization function between all TIO constructors.
@@ -374,6 +384,9 @@ public:
     double m_dVisualResampleRate;
     Segmentation<QString> m_chordData;
 
+    // Storage for the track's beats
+    BeatsPointer m_pBeats;
+
     friend class TrackDAO;
 };
 
