@@ -14,30 +14,20 @@
 #include "widget/wskincolor.h"
 #include "widget/wwidget.h"
 #include "trackinfoobject.h"
+#include "track/beats.h"
+
 
 WaveformRenderBeat::WaveformRenderBeat(const char* group, WaveformRenderer *parent)
         : m_pParent(parent),
-          m_pBpm(NULL),
-          m_pBeatFirst(NULL),
           m_pTrackSamples(NULL),
           m_pTrack(),
           m_iWidth(0),
           m_iHeight(0),
-          m_dBpm(-1),
-          m_dBeatFirst(-1),
           m_dSamplesPerPixel(-1),
           m_dSamplesPerDownsample(-1),
-          m_dBeatLength(-1),
           m_iNumSamples(0),
-          m_iSampleRate(0) {
-    m_pBpm = new ControlObjectThreadMain(
-        ControlObject::getControl(ConfigKey(group, "file_bpm")));
-    connect(m_pBpm, SIGNAL(valueChanged(double)),
-            this, SLOT(slotUpdateBpm(double)));
-
-    //m_pBeatFirst = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey(group, "BeatFirst")));
-    //connect(m_pBeatFirst, SIGNAL(valueChanged(double)), this, SLOT(slotUpdateBeatFirst(double)));
-
+          m_iSampleRate(0),
+          m_bBeatActive(false) {
     m_pTrackSamples = new ControlObjectThreadMain(
         ControlObject::getControl(ConfigKey(group,"track_samples")));
     slotUpdateTrackSamples(m_pTrackSamples->get());
@@ -49,17 +39,18 @@ WaveformRenderBeat::WaveformRenderBeat(const char* group, WaveformRenderer *pare
     slotUpdateTrackSampleRate(m_pTrackSampleRate->get());
     connect(m_pTrackSampleRate, SIGNAL(valueChanged(double)),
             this, SLOT(slotUpdateTrackSampleRate(double)));
+
+    m_pBeatActive = new ControlObjectThreadMain(
+        ControlObject::getControl(ConfigKey(group,"beat_active")));
+    slotUpdateBeatActive(m_pBeatActive->get());
+    connect(m_pBeatActive, SIGNAL(valueChanged(double)),
+            this, SLOT(slotUpdateBeatActive(double)));
 }
 
-void WaveformRenderBeat::slotUpdateBpm(double v) {
-    //qDebug() << "WaveformRenderBeat :: BPM = " << v;
-    m_dBpm = v;
-    m_dBeatLength = -1;
-}
-
-void WaveformRenderBeat::slotUpdateBeatFirst(double v) {
-    //qDebug() << "WaveformRenderBeat :: beatFirst = " << v;
-    m_dBeatFirst = v;
+WaveformRenderBeat::~WaveformRenderBeat() {
+   delete m_pTrackSamples;
+   delete m_pBeatActive;
+    qDebug() << this << "~WaveformRenderBeat()";
 }
 
 void WaveformRenderBeat::slotUpdateTrackSamples(double samples) {
@@ -68,7 +59,7 @@ void WaveformRenderBeat::slotUpdateTrackSamples(double samples) {
 }
 
 void WaveformRenderBeat::slotUpdateTrackSampleRate(double sampleRate) {
-    //qDebug() << "WaveformRenderBeat :: sampleRate = " << int(sampleRate);
+
 
     // f = z * m * n
     double m = m_pParent->getSubpixelsPerPixel();
@@ -78,7 +69,15 @@ void WaveformRenderBeat::slotUpdateTrackSampleRate(double sampleRate) {
 
     m_iSampleRate = static_cast<int>(sampleRate);
     m_dSamplesPerDownsample = n;
-    m_dSamplesPerPixel = static_cast<double>(f)/z;
+    m_dSamplesPerPixel = f/z;
+
+    //qDebug() << "WaveformRenderBeat :: sampleRate = " << int(sampleRate)
+    //         << "samplesPerDownsample" << m_dSamplesPerDownsample
+    //         << "samplesPerPixel" << m_dSamplesPerPixel;
+}
+
+void WaveformRenderBeat::slotUpdateBeatActive(double beatActive) {
+    m_bBeatActive = beatActive > 0;
 }
 
 void WaveformRenderBeat::resize(int w, int h) {
@@ -88,14 +87,9 @@ void WaveformRenderBeat::resize(int w, int h) {
 
 void WaveformRenderBeat::newTrack(TrackPointer pTrack) {
     m_pTrack = pTrack;
-    m_dBpm = -1;
-    m_dBeatFirst = -1;
-    m_dBeatLength = -1;
-    //qDebug() << "WaveformRenderBeat sampleRate  " << sampleRate << " samplesPerPixel " << m_dSamplesPerPixel;
 }
 
 void WaveformRenderBeat::setup(QDomNode node) {
-
     colorMarks.setNamedColor(WWidget::selectNodeQString(node, "BeatColor"));
     colorMarks = WSkinColor::getCorrectColor(colorMarks);
 
@@ -107,10 +101,9 @@ void WaveformRenderBeat::setup(QDomNode node) {
     colorHighlight = WSkinColor::getCorrectColor(colorHighlight);
 }
 
-
-void WaveformRenderBeat::draw(QPainter *pPainter, QPaintEvent *event, QVector<float> *buffer, double dPlayPos, double rateAdjust) {
-    if(m_dBpm == -1 || m_dBpm == 0)
-        return;
+void WaveformRenderBeat::draw(QPainter *pPainter, QPaintEvent *event,
+                              QVector<float> *buffer, double dPlayPos, double rateAdjust) {
+    slotUpdateTrackSamples(m_pTrackSamples->get());
 
     if(m_iSampleRate <= 0 || m_iNumSamples == 0)
         return;
@@ -118,8 +111,11 @@ void WaveformRenderBeat::draw(QPainter *pPainter, QPaintEvent *event, QVector<fl
     if(buffer == NULL)
         return;
 
-    int iCurPos = (int)(dPlayPos * m_iNumSamples);
+    BeatsPointer pBeats = m_pTrack->getBeats();
+    if (!pBeats)
+        return;
 
+    int iCurPos = (int)(dPlayPos * m_iNumSamples);
     if(iCurPos % 2 != 0)
         iCurPos--;
 
@@ -134,44 +130,41 @@ void WaveformRenderBeat::draw(QPainter *pPainter, QPaintEvent *event, QVector<fl
     // Therefore, sample s is a beat if it satisfies  s % 60f/b == 0.
     // where s is a /mono/ sample
 
-    // beat length in samples
-    if(m_dBeatLength <= 0) {
-        m_dBeatLength = 60.0 * m_iSampleRate / m_dBpm;
-    }
-
     double subpixelsPerPixel = m_pParent->getSubpixelsPerPixel()*(1.0+rateAdjust);
-    const int oversample = (int)subpixelsPerPixel;
+
+    QPen marksPen(colorMarks);
+    marksPen.setWidth(subpixelsPerPixel*1.5);
+    QPen highlightPen(colorHighlight);
+    highlightPen.setWidth(subpixelsPerPixel*1.5);
 
     pPainter->save();
     pPainter->scale(1.0/subpixelsPerPixel,1.0);
-    pPainter->setPen(colorMarks);
+
+    pPainter->setPen(marksPen);
 
     double subpixelWidth = m_iWidth * subpixelsPerPixel;
     double subpixelHalfWidth = subpixelWidth / 2.0;
-    double halfw = m_iWidth/2;
     double halfh = m_iHeight/2;
 
-    // NOTE: converting curpos from stereo samples to mono samples
-    iCurPos = iCurPos >> 1;
-
     // basePos and endPos are in samples
-    double basePos = iCurPos - m_dSamplesPerPixel*halfw*(1.0+rateAdjust);
-    double endPos = basePos + m_iWidth*m_dSamplesPerPixel*(1.0+rateAdjust);
+    double basePos = iCurPos - m_dSamplesPerPixel * m_iWidth * (1.0+rateAdjust);
+    double endPos = basePos + (2 * m_iWidth) * m_dSamplesPerPixel * (1.0+rateAdjust);
 
-    // snap to the first beat
-    double curPos = ceilf(basePos/m_dBeatLength)*m_dBeatLength;
+
+    m_beatList.clear();
+    pBeats->findBeats(basePos, endPos, &m_beatList);
 
     bool reset = false;
-    for(;curPos <= endPos; curPos+=m_dBeatLength) {
-        if(curPos < 0)
+    foreach (double curPos, m_beatList) {
+        if (curPos < 0)
             continue;
 
         // i relative to the current play position in subpixels
-        double i = (curPos - iCurPos)/m_dSamplesPerDownsample;
+        double i = (((curPos) - iCurPos)/2)/m_dSamplesPerDownsample;
 
-        // If i is less than 20 subpixels from center, highlight it.
-        if(abs(i) < 20) {
-            pPainter->setPen(colorHighlight);
+        // If a beat is active, highlight the marker.
+        if(m_bBeatActive && abs(i) < 20) {
+            pPainter->setPen(highlightPen);
             reset = true;
         }
 
@@ -181,11 +174,10 @@ void WaveformRenderBeat::draw(QPainter *pPainter, QPaintEvent *event, QVector<fl
         pPainter->drawLine(QLineF(i,halfh,i,-halfh));
 
         if(reset) {
-            pPainter->setPen(colorMarks);
+            pPainter->setPen(marksPen);
             reset = false;
         }
     }
 
     pPainter->restore();
-
 }
