@@ -1,4 +1,3 @@
-
 #include <QDebug>
 #include <QColor>
 #include <QDomNode>
@@ -24,21 +23,18 @@ WaveformRenderSignal::WaveformRenderSignal(const char* group, WaveformRenderer *
     m_fGain(1),
     m_lines(0),
     m_pTrack(NULL),
-
     signalColor(255,255,255) {
-
     m_pGain = new ControlObjectThreadMain(
         ControlObject::getControl(ConfigKey(group, "total_gain")));
-    if(m_pGain != NULL) {
+    if (m_pGain != NULL) {
         connect(m_pGain, SIGNAL(valueChanged(double)),
                 this, SLOT(slotUpdateGain(double)));
     }
 }
 
 WaveformRenderSignal::~WaveformRenderSignal() {
-    if(m_pGain)
-        delete m_pGain;
-    m_pGain = NULL;
+    qDebug() << this << "~WaveformRenderSignal()";
+    delete m_pGain;
 }
 
 void WaveformRenderSignal::resize(int w, int h) {
@@ -60,26 +56,27 @@ void WaveformRenderSignal::setup(QDomNode node) {
 }
 
 
-void WaveformRenderSignal::draw(QPainter *pPainter, QPaintEvent *event, QVector<float> *buffer, double dPlayPos, double rateAdjust) {
-    if(buffer == NULL)
+void WaveformRenderSignal::draw(QPainter *pPainter, QPaintEvent *event,
+                                QVector<float> *buffer, double dPlayPos,
+                                double rateAdjust) {
+    if (buffer == NULL) {
         return;
+    }
 
-    float* baseBuffer = buffer->data();
+    const float* baseBuffer = buffer->constData();
 
     int numBufferSamples = buffer->size();
     int iCurPos = 0;
-    if(dPlayPos >= 0) {
-        iCurPos = (int)(dPlayPos*numBufferSamples);
-    }
+    iCurPos = (int)(dPlayPos*numBufferSamples);
 
-    if((iCurPos % 2) != 0)
+    if ((iCurPos % 2) != 0)
         iCurPos--;
 
     pPainter->save();
 
     pPainter->setPen(signalColor);
 
-    double subpixelsPerPixel = m_pParent->getSubpixelsPerPixel() * (1.0 + rateAdjust);
+    const double subpixelsPerPixel = m_pParent->getSubpixelsPerPixel() * (1.0 + rateAdjust);
 
     int subpixelWidth = int(m_iWidth * subpixelsPerPixel);
 
@@ -112,6 +109,24 @@ void WaveformRenderSignal::draw(QPainter *pPainter, QPaintEvent *event, QVector<
     // Only draw lines that we have provided
     pPainter->drawLines(lineData, subpixelWidth);
 
-    pPainter->restore();
+    // Some of the pre-roll is on screen. Draw little triangles to indicate
+    // where the pre-roll is located.
+    if (iCurPos < 2*halfw) {
+        double start_index = 0;
+        int end_index = (halfw - iCurPos/2);
+        QPolygonF polygon;
+        const int polyWidth = 80;
+        polygon << QPointF(0, 0)
+                << QPointF(-polyWidth/subpixelsPerPixel, -m_iHeight/5)
+                << QPointF(-polyWidth/subpixelsPerPixel, m_iHeight/5);
+        polygon.translate(end_index/subpixelsPerPixel, 0);
 
+        int index = end_index;
+        while (index > start_index) {
+            pPainter->drawPolygon(polygon);
+            polygon.translate(-polyWidth/subpixelsPerPixel, 0);
+            index -= polyWidth;
+        }
+    }
+    pPainter->restore();
 }
