@@ -22,18 +22,19 @@ class SoundSourceProxy;
 
 class WaveformRenderSignal : public RenderObject {
     Q_OBJECT
-public:
+  public:
     WaveformRenderSignal(const char *group, WaveformRenderer *parent);
-    ~WaveformRenderSignal();
+    virtual ~WaveformRenderSignal();
+
     void resize(int w, int h);
     void setup(QDomNode node);
     void draw(QPainter *pPainter, QPaintEvent *event, QVector<float> *buffer, double playPos, double rateAdjust);
     void newTrack(TrackPointer pTrack);
 
-public slots:
+  public slots:
     void slotUpdateGain(double gain);
 
-private:
+  private:
     float m_fGain;
 
     WaveformRenderer *m_pParent;
