@@ -12,7 +12,6 @@
 WNumberPos::WNumberPos(const char * group, QWidget * parent)
         : WNumber(parent),
           m_dOldValue(0.0f),
-          m_dDuration(0.0f),
           m_dTrackSamples(0.0),
           m_dTrackSampleRate(0.0f),
           m_bRemain(false) {
@@ -23,19 +22,12 @@ WNumberPos::WNumberPos(const char * group, QWidget * parent)
             this, SLOT(slotSetRemain(double)));
     slotSetRemain(m_pShowDurationRemaining->get());
 
+    // TODO(xxx) possible unused m_pRateControl and m_pRateDirControl?
     m_pRateControl = new ControlObjectThreadWidget(
         ControlObject::getControl(ConfigKey(group, "rate")));
     m_pRateDirControl = new ControlObjectThreadWidget(
         ControlObject::getControl(ConfigKey(group, "rate_dir")));
 
-    m_pDuration = new ControlObjectThreadWidget(
-        ControlObject::getControl(ConfigKey(group, "duration")));
-    connect(m_pDuration, SIGNAL(valueChanged(double)),
-            this, SLOT(slotSetTrackDuration(double)));
-    // Tell the CO to re-emit its value since we could be created after it was
-    // set to a valid value.
-    m_pDuration->emitValueChanged();
-
     m_pTrackSamples = new ControlObjectThreadWidget(
         ControlObject::getControl(ConfigKey(group, "track_samples")));
     connect(m_pTrackSamples, SIGNAL(valueChanged(double)),
@@ -54,6 +46,11 @@ WNumberPos::WNumberPos(const char * group, QWidget * parent)
 }
 
 WNumberPos::~WNumberPos() {
+    delete m_pTrackSampleRate;
+    delete m_pTrackSamples;
+    delete m_pShowDurationRemaining;
+    delete m_pRateControl;
+    delete m_pRateDirControl;
 }
 
 void WNumberPos::mousePressEvent(QMouseEvent* pEvent) {
@@ -65,11 +62,6 @@ void WNumberPos::mousePressEvent(QMouseEvent* pEvent) {
     }
 }
 
-void WNumberPos::slotSetTrackDuration(double dDuration) {
-    m_dDuration = dDuration;
-    setValue(m_dOldValue);
-}
-
 void WNumberPos::slotSetTrackSamples(double dSamples) {
     m_dTrackSamples = dSamples;
     setValue(m_dOldValue);
@@ -85,25 +77,29 @@ void WNumberPos::setValue(double dValue) {
 
     double valueMillis = 0.0f;
     double durationMillis = 0.0f;
-    if (m_dTrackSamples > 0 && m_dTrackSampleRate > 0 && m_dDuration > 0) {
-        valueMillis = dValue * 1000.0f * m_dTrackSamples / 2.0f / 127.0f / m_dTrackSampleRate;
-        durationMillis = m_dDuration * 1000.0f;
+    if (m_dTrackSamples > 0 && m_dTrackSampleRate > 0) {
+        //map midi value taking in to account 14 = 0 and 114 = 1
+        double dDuration = m_dTrackSamples / m_dTrackSampleRate / 2.0;
+        valueMillis = (dValue - 14) * 1000.0f * m_dTrackSamples / 2.0f / 100.0f / m_dTrackSampleRate;
+        durationMillis = dDuration * 1000.0f;
         if (m_bRemain)
             valueMillis = math_max(durationMillis - valueMillis, 0.0f);
     }
 
-    QTime valueTime = QTime().addMSecs(valueMillis);
-    QTime durationTime = QTime().addMSecs(durationMillis);
-
-    QString valueString = valueTime.toString((valueTime.hour() >= 1) ? "hh:mm:ss.zzz" : "mm:ss.zzz");
-    QString durationString = durationTime.toString((durationTime.hour() >= 1) ? "hh:mm:ss.zzz" : "mm:ss.zzz");
+    QString valueString;
+    if (valueMillis >= 0) {
+        QTime valueTime = QTime().addMSecs(valueMillis);
+        valueString = valueTime.toString((valueTime.hour() >= 1) ? "hh:mm:ss.zzz" : "mm:ss.zzz");
+    } else {
+        QTime valueTime = QTime().addMSecs(0 - valueMillis);
+        valueString = valueTime.toString((valueTime.hour() >= 1) ? "-hh:mm:ss.zzz" : "-mm:ss.zzz");
+    }
 
     // The format string gives us one extra digit of millisecond precision than
     // we care about. Slice it off.
     valueString = valueString.left(valueString.length() - 1);
-    durationString = durationString.left(durationString.length() - 1);
 
-    m_pLabel->setText(QString("%1%2   %3").arg(m_qsText).arg(valueString).arg(durationString));
+    m_pLabel->setText(QString("%1%2").arg(m_qsText).arg(valueString));
 }
 
 void WNumberPos::slotSetRemain(double remain) {
