@@ -17,8 +17,16 @@
 WNumberRate::WNumberRate(const char * group, QWidget * parent) : WNumber(parent)
 {
     m_pRateRangeControl = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey(group, "rateRange")));
+    connect(m_pRateRangeControl, SIGNAL(valueChanged(double)),
+            this, SLOT(setValue(double)));
     m_pRateDirControl = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey(group, "rate_dir")));
+    connect(m_pRateDirControl, SIGNAL(valueChanged(double)),
+            this, SLOT(setValue(double)));
     m_pRateControl = new ControlObjectThreadMain(ControlObject::getControl(ConfigKey(group, "rate")));
+    connect(m_pRateControl, SIGNAL(valueChanged(double)),
+            this, SLOT(setValue(double)));
+    // Initialize the widget.
+    setValue(0);
 }
 
 WNumberRate::~WNumberRate()
@@ -39,4 +47,3 @@ void WNumberRate::setValue(double)
 
     m_pLabel->setText(QString(m_qsText).append(sign).append("%1").arg(fabs(vsign)*100., 0, 'f', 2));
 }
-
