@@ -42,6 +42,7 @@ class WOverview : public WWidget
     void mouseReleaseEvent(QMouseEvent *e);
     void mousePressEvent(QMouseEvent *e);
     void paintEvent(QPaintEvent *);
+    void paintTrackProgress(QPainter& painter);
     void redrawPixmap();
     QColor getMarkerColor();
     QColor getSignalColor();
@@ -49,8 +50,9 @@ class WOverview : public WWidget
   public slots:
     void setValue(double);
     void slotLoadNewWaveform(TrackInfoObject* pTrack);
-    void slotLoadNewWaveform(TrackPointer pTrack);
+    void slotTrackLoaded(TrackPointer pTrack);
     void slotUnloadTrack(TrackPointer pTrack);
+    void slotTrackProgress(TrackPointer pTrack, int progress);
 
   signals:
     void trackDropped(QString filename, QString group);
@@ -69,6 +71,11 @@ class WOverview : public WWidget
     const char* m_pGroup;
     bool waveformChanged;
 
+    // Current active track
+    TrackPointer m_pCurrentTrack;
+    bool m_analysing;
+    int m_iProgress;
+
     // Loop controls and values
     ControlObject* m_pLoopStart;
     ControlObject* m_pLoopEnd;
@@ -91,9 +98,13 @@ class WOverview : public WWidget
     int m_iPos, m_iStartMousePos;
     /** Pointer to screen buffer */
     QPixmap *m_pScreenBuffer;
+    QPixmap m_backgroundPixmap;
+    QString m_backgroundPixmapPath;
     QColor m_qColorBackground;
     QColor m_qColorMarker;
     QColor m_qColorSignal;
+    QColor m_qColorProgress;
+    int m_iProgressAlpha;
 };
 
 #endif
