@@ -46,13 +46,16 @@ class WTrackTableView : public WLibraryTableView
     void slotNextTrackInfo();
     void slotPrevTrackInfo();
     void slotSendToAutoDJ();
+    void slotSendToAutoDJTop();
     void slotReloadTrackMetadata();
+    void slotResetPlayed();
     void addSelectionToPlaylist(int iPlaylistId);
     void addSelectionToCrate(int iCrateId);
     void loadSelectionToGroup(QString group);
     void doSortByColumn(int headerSection);
 
   private:
+    void sendToAutoDJ(bool bTop);
     void showTrackInfo(QModelIndex index);
     void createActions();
     void dragMoveEvent(QDragMoveEvent * event);
@@ -89,10 +92,14 @@ class WTrackTableView : public WLibraryTableView
 
     // Send to Auto-DJ Action
     QAction *m_pAutoDJAct;
+    QAction *m_pAutoDJTopAct;
 
     // Remove from table
     QAction *m_pRemoveAct;
 
+    // Reset the played count of selected track or tracks
+    QAction* m_pResetPlayedAct;
+
     // Show track-editor action
     QAction *m_pPropertiesAct;
 };
